#
# spec file for package libguestfs
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libguestfs
ExclusiveArch:  x86_64 ppc64 ppc64le s390x aarch64 riscv64
Version:        1.55.3
Release:        1.1
Summary:        Access and modify virtual machine disk images
License:        GPL-2.0-or-later
URL:            http://libguestfs.org

Source0:        %{name}-%{version}.tar.gz
Source1:        %{name}-%{version}.tar.gz.sig
Source3:        libguestfs.rpmlintrc
Source5:        guestfish.sh
Source100:      mount-rootfs-and-chroot.sh
Source101:      README

# Patches
Patch1:         use-rtc-driftfix-slew-for-x86-only.patch

BuildRequires:  bison
BuildRequires:  file-devel
BuildRequires:  flex
BuildRequires:  gawk
BuildRequires:  gcc-c++
BuildRequires:  gobject-introspection-devel
BuildRequires:  gperf
BuildRequires:  libjson-c-devel
BuildRequires:  libtool
BuildRequires:  ocaml-augeas-devel
BuildRequires:  ocaml-hivex-devel
BuildRequires:  ocaml-rpm-macros
BuildRequires:  po4a
BuildRequires:  readline-devel
BuildRequires:  supermin >= 5.1.18
BuildRequires:  zstd
BuildRequires:  ocaml(ocaml_base_version) >= 4.08
BuildRequires:  ocamlfind(findlib)
BuildRequires:  perl(Getopt::Long)
BuildRequires:  perl(Locale::TextDomain)
BuildRequires:  perl(Module::Build)
BuildRequires:  perl(Pod::Man)
BuildRequires:  perl(Pod::Simple)
BuildRequires:  perl(Pod::Usage)
BuildRequires:  perl(Test::More)
BuildRequires:  pkgconfig(augeas)
BuildRequires:  pkgconfig(bash-completion)
BuildRequires:  pkgconfig(fuse)
BuildRequires:  pkgconfig(hivex)
BuildRequires:  pkgconfig(jansson)
BuildRequires:  pkgconfig(libacl)
BuildRequires:  pkgconfig(libcap)
BuildRequires:  pkgconfig(libconfig)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libpcre2-8)
BuildRequires:  pkgconfig(libtirpc)
BuildRequires:  pkgconfig(libvirt)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(rpm) >= 4.6.0
BuildRequires:  pkgconfig(tinfo)

Requires:       libguestfs-appliance
Obsoletes:      guestfs-tools <= 1.44.2

%description
Libguestfs is a library for accessing and modifying virtual machine
disk images.  http://libguestfs.org

Libguestfs uses Linux kernel and qemu code, and can access any type of
guest filesystem that Linux and qemu can, including but not limited
to: ext2/3/4, btrfs, FAT and NTFS, LVM, many different disk partition
schemes, qcow, qcow2, vmdk.

%prep
%autosetup -p1

sed -i 's|RPMVSF_MASK_NOSIGNATURES|_RPMVSF_NOSIGNATURES|' daemon/rpm-c.c
sed -i 's/tar zcf/tar -zcf/' appliance/Makefile.am

%build
# provide a wrapper to tar that creates bit-reproducible output (boo#1218191)
# used in supermin for base.tar.gz, in %install for zz-winsupport.tar.gz zz-scripts.tar.gz and in appliance/Makefile.am for 3 more .tar.gz files
SOURCE_DATE_EPOCH=${SOURCE_DATE_EPOCH:-$(date -r %{SOURCE0} +%%s)}
mkdir -p ~/bin ; cat >~/bin/tar <<EOF
#!/bin/sh
exec /usr/bin/tar \
  --sort=name --clamp-mtime --mtime=@$SOURCE_DATE_EPOCH \
  --owner=0 --group=0 --numeric-owner \
  --pax-option=exthdr.name=%%d/PaxHeaders/%%f,delete=atime,delete=ctime \
  "\$@"
EOF
chmod a+x ~/bin/tar
PATH=~/bin:$PATH

%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
# use 'env LIBGUESTFS_HV=/path/to/kvm libguestfs-test-tool' to verify
%define kvm_binary /bin/false
%ifarch aarch64
%define kvm_binary %{_bindir}/qemu-system-aarch64
%endif
%ifarch ppc64le
%define kvm_binary %{_bindir}/qemu-system-ppc64
%endif
%ifarch ppc64
%define kvm_binary %{_bindir}/qemu-system-ppc64
%endif
%ifarch riscv64
%define kvm_binary %{_bindir}/qemu-system-riscv64
%endif
%ifarch s390x
%define kvm_binary %{_bindir}/qemu-system-s390x
%endif
%ifarch x86_64
%define kvm_binary %{_bindir}/qemu-system-x86_64
%endif
#
%define guestfs_docdir %{_defaultdocdir}/%{name}

export AWK='%{_bindir}/gawk'
export CPIO='%{_bindir}/cpio'
export GPERF='%{_bindir}/gperf'
export MKISOFS='%{_bindir}/xorrisofs'
export XMLLINT='%{_bindir}/xmllint'
export PO4A_GETTEXTIZE='%{_bindir}/po4a-gettextize'
export PO4A_TRANSLATE='%{_bindir}/po4a-translate'
export SQLITE3='%{_bindir}/sqlite3'
export PBMTEXT='%{_bindir}/pbmtext'
export PNMTOPNG='%{_bindir}/pnmtopng'
export BMPTOPNM='%{_bindir}/bmptopnm'
export PAMCUT='%{_bindir}/pamcut'
export WRESTOOL='%{_bindir}/wrestool'
export XZCAT='%{_bindir}/xzcat'
export VALGRIND='%{_bindir}/valgrind'
export FUSER='%{_bindir}/fuser'
export TOOL_TRUE='%{_bindir}/true'
export XGETTEXT='%{_bindir}/xgettext'
export MSGCAT='%{_bindir}/msgcat'
export MSGFMT='%{_bindir}/msgfmt'
export MSGMERGE='%{_bindir}/msgmerge'
export RPCGEN='%{_bindir}/rpcgen'
export SUPERMIN='%{_bindir}/supermin'
export QEMU="%{kvm_binary}"
export vmchannel_test=no
export PERL='%{_bindir}/perl'
export PYTHON='%{_bindir}/python3'

sed -i~ '
/test-data/d
' configure.ac
diff -u "$_"~ "$_" && exit 0
sed -i~ '
/SUBDIRS/s@test-data@@
' Makefile.am
diff -u "$_"~ "$_" && exit 0
autoreconf -fi

%configure --help
%configure \
        --docdir=%{guestfs_docdir} \
	--with-distro=SUSE \
	--with-readline \
        --with-guestfs-path=%{_libdir}/guestfs \
        --with-qemu=$QEMU \
        --with-supermin-packager-config="$PWD/zypper.priv.conf --use-installed --verbose" \
        --without-java \
        --enable-appliance-format-auto \
        --enable-daemon \
	--enable-install-daemon \
        --enable-ocaml \
        --enable-perl \
        --enable-python \
        --disable-erlang \
        --disable-haskell \
        --disable-php \
        --disable-rpath \
        --disable-static \
	%nil

# 'INSTALLDIRS' ensures that perl libs are installed in the vendor dir instead of the site dir
build_it() {
make \
	INSTALLDIRS=vendor \
	LD_RUN_PATH= \
	"$@"
}

build_it %{?_smp_mflags} || build_it

%install
PATH=~/bin:$PATH
%make_install \
	INSTALLDIRS=vendor \
	udevrulesdir=%{_udevrulesdir}
find %buildroot -ls

rm -f $( find %buildroot -name '*.a' | grep -v /ocaml/ )

find %buildroot -name '*.la' -delete

mkdir -p %{buildroot}/etc/profile.d
cp %{S:5} %{buildroot}/etc/profile.d

# Perl
find %{buildroot}/ -name "*.bs" -size 0c -print -delete
%perl_process_packlist

# OCaml
%ocaml_create_file_list
# Supermin
# Use RPMs from packagelist for the packages file. Sort and clean leading whitespace.
sort -u appliance/packagelist | awk '{$1=$1};1' > %buildroot%_libdir/guestfs/supermin.d/packages
pushd $RPM_BUILD_ROOT%{_libdir}/guestfs/supermin.d

function remove
{
    grep -Ev "^$1$" < packages > packages-t
    mv packages-t packages
}

function move_to
{
    if ! grep -Esq "^$1$" packages; then
        echo "move_to $1: package name not found in packages file"
        exit 1
    fi
    remove "$1"
    echo "$1" >> "$2"
}

move_to iputils         zz-packages-rescue
move_to lsof            zz-packages-rescue
move_to pciutils        zz-packages-rescue
move_to strace          zz-packages-rescue
move_to vim             zz-packages-rescue
move_to rsync           zz-packages-rsync
move_to xfsprogs        zz-packages-xfs

popd

# Remove the .gitignore file from ocaml/html which will be copied to docdir.
rm ocaml/html/.gitignore

%find_lang %{name}

# Appliance NTFS files
# Just copy the content of the ntfs packages
mkdir winsupport
for pkg in $(rpm -qa | grep ntfs); do
    rpm -ql $pkg > $pkg.list
    rsync -av --files-from $pkg.list / winsupport
done

cp %{S:101} winsupport

pushd winsupport
tar -czf %{buildroot}%{_libdir}/guestfs/supermin.d/zz-winsupport.tar.gz .
popd

cat > %{buildroot}%{_libdir}/guestfs/supermin.d/zz-packages-winsupport << EOF
libfuse2
hwinfo
EOF

# Do some cleanup so that rpm can properly empty directories without permission denied
# The winsupport directory has already been tar'ed up, so we don't care much
find winsupport -type d -exec chmod 755 {} \;

mkdir -p %{buildroot}/tmp/usr/bin
cp %{S:100} %{buildroot}/tmp/usr/bin
chmod a+x %{buildroot}/tmp/usr/bin/*
pushd %{buildroot}/tmp
tar -czf %{buildroot}/%{_libdir}/guestfs/supermin.d/zz-scripts.tar.gz usr
popd
rm -rf %{buildroot}/tmp

%package -n libguestfs0
Summary:        Runtime library of libguestfs
Requires:       %{kvm_binary}

%description -n libguestfs0
Shared object library for libguestfs tools which are used to access
and modify virtual machines.

%package -n libguestfsd
Summary:        Daemon for the libguestfs appliance
Provides:       guestfsd = %{version}
Obsoletes:      guestfsd < %{version}

%description -n libguestfsd
guestfsd runs within the libguestfs appliance. It receives commands from the host
and performs the requested action by calling the helper binaries.
This package is only required for building the appliance.

%package -n libguestfs-appliance
BuildRequires:  augeas-lenses
BuildRequires:  bc
BuildRequires:  btrfsprogs
BuildRequires:  bzip2
BuildRequires:  coreutils
BuildRequires:  cpio
BuildRequires:  cryptsetup
BuildRequires:  dhcp-client
BuildRequires:  diffutils
BuildRequires:  dosfstools
BuildRequires:  e2fsprogs
BuildRequires:  file
BuildRequires:  findutils
BuildRequires:  glibc
BuildRequires:  gptfdisk
BuildRequires:  grep
BuildRequires:  gzip
BuildRequires:  initviocons
BuildRequires:  iproute2
BuildRequires:  jfsutils
BuildRequires:  ldmtool
BuildRequires:  lvm2
BuildRequires:  mdadm
BuildRequires:  mkisofs
BuildRequires:  module-init-tools
BuildRequires:  ncurses-utils
BuildRequires:  nfs-client
BuildRequires:  ntfs-3g
BuildRequires:  ntfsprogs
BuildRequires:  pam-config
BuildRequires:  parted
BuildRequires:  psmisc
BuildRequires:  sg3_utils
BuildRequires:  strace
BuildRequires:  sysconfig-netconfig
%ifarch %ix86 x86_64
BuildRequires:  syslinux
%endif
BuildRequires:  tar
BuildRequires:  terminfo-base
BuildRequires:  tunctl
BuildRequires:  udev
BuildRequires:  util-linux
BuildRequires:  util-linux-lang
BuildRequires:  xfsprogs
BuildRequires:  xz

# Needed by guestfsd which is burried in the appliance
#
# The problem with this design is that rpm can't find the
# library dependencies from the guestfsd hidden in the
# daemon.tar.gz tarball. Supermin will compute an appliance
# at runtime based on the packages it will find on the host.
# Thus if there is no libaugeas, libhivex, etc on the host,
# the appliance will fail to start the guestfsd.
Requires:       augeas
Requires:       augeas-lenses
Requires:       dhcp-client
Requires:       libaugeas0
Requires:       libcap2
Requires:       libguestfs0
Requires:       libhivex0
Requires:       libpcre1

# For core disk features
Requires:       qemu-tools
Requires:       btrfsprogs
Requires:       cryptsetup
Requires:       dosfstools
Requires:       e2fsprogs
Requires:       gptfdisk
Requires:       jfsutils
Requires:       ldmtool
Requires:       mdadm
Requires:       mkisofs
Recommends:     ntfsprogs
Requires:       parted
Requires:       supermin >= 5.1.18
Requires:       xfsprogs
Recommends:     zerofree

Summary:        Virtual machine needed for libguestfs
Provides:       guestfs-data = %{version}
Obsoletes:      guestfs-data < %{version}

%description -n libguestfs-appliance
libguestfs-appliance provides the appliance used by libguestfs.

%package winsupport
Summary:        Windows guest support in libguestfs
Requires:       libguestfs >= 1.32
BuildRequires:  ntfs-3g
BuildRequires:  ntfsprogs
BuildRequires:  rsync
Requires:       ntfs-3g
Requires:       ntfsprogs
Provides:       guestfs-winsupport = %{version}
Obsoletes:      guestfs-winsupport < %{version}

%description winsupport
Provides the needed pieces for libguestfs to handle Windows guests.

%package devel
Summary:        Development files for libguestfs
Requires:       libguestfs0 = %{version}

%description devel
Development files for libguestfs.

libguestfs is a set of tools for accessing and modifying virtual machine (VM)
disk images. You can use this for viewing and editing files inside guests,
scripting changes to VMs, monitoring disk used/free statistics, P2V, V2V,
performing partial backups, cloning VMs, and much else besides.

%package bash-completion
Summary:        Bash tab-completion scripts for %{name} tools
BuildArch:      noarch
Requires:       bash-completion >= 2.0

%description bash-completion
Install this package if you want intelligent bash tab-completion
for guestfish, guestmount and various virt-* tools.

%package inspect-icons
Summary:        Additional dependencies for inspecting guest icons
BuildArch:      noarch
Requires:       %{name} = %{version}-%{release}
%if 0%{?suse_version} > 1500
Requires:       icoutils
%endif

%description inspect-icons
%{name}-inspect-icons is a metapackage that pulls in additional
dependencies required by libguestfs to pull icons out of non-Linux
guests.  Install this package if you want libguestfs to be able to
inspect non-Linux guests and display icons from them.

The only reason this is a separate package is to avoid core libguestfs
having to depend on Perl.

%package -n ocaml-%{name}
Summary:        OCaml bindings for %{name}
Requires:       %{name} = %{version}-%{release}

%description -n ocaml-%{name}
ocaml-%{name} contains OCaml bindings for %{name}.

This is for toplevel and scripting access only.  To compile OCaml
programs which use %{name} you will also need ocaml-%{name}-devel.

%package -n ocaml-%{name}-devel
Summary:        OCaml bindings for %{name}
Requires:       ocaml-%{name} = %{version}-%{release}

%description -n ocaml-%{name}-devel
ocaml-%{name}-devel contains development libraries
required to use the OCaml bindings for %{name}.

%package -n perl-Sys-Guestfs
Summary:        Perl bindings for %{name} (Sys::Guestfs)
Requires:       %{name} = %{version}-%{release}
Requires:       perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))

%description -n perl-Sys-Guestfs
perl-Sys-Guestfs contains Perl bindings for %{name} (Sys::Guestfs).

%package -n python3-%{name}
Summary:        Python 3 bindings for %{name}
BuildRequires:  python-rpm-macros
Requires:       %{name} = %{version}-%{release}
%{?python_provide:%python_provide python3-%{name}}

%description -n python3-%{name}
python3-%{name} contains Python 3 bindings for %{name}.

%package -n rubygem-%{name}
Summary:        Ruby bindings for %{name}
BuildRequires:  ruby
BuildRequires:  ruby-devel
BuildRequires:  rubygem(rake)
Requires:       %{name} = %{version}-%{release}
Requires:       ruby

%description -n rubygem-%{name}
ruby-%{name} contains Ruby bindings for %{name}.

%package -n lua-%{name}
Summary:        Lua bindings for %{name}
BuildRequires:  lua-devel
Requires:       %{name} = %{version}-%{release}
Requires:       lua

%description -n lua-%{name}
lua-%{name} contains Lua bindings for %{name}.

%package gobject-1_0
Summary:        GObject bindings for %{name}
Requires:       %{name} = %{version}-%{release}
Obsoletes:      libguestfs0 <= 1.44.2

%description gobject-1_0
%{name}-gobject-1_0 contains GObject bindings for %{name}.

To develop software against these bindings, you need to install
%{name}-gobject-devel.

%package typelib-Guestfs-1_0
Summary:        Libguestfs GObject introspection data
Group:          System/Libraries

%description typelib-Guestfs-1_0
This package contains the GObject introspection data.

%package gobject-devel
Summary:        GObject bindings for %{name}
Requires:       %{name}-gobject-1_0 = %{version}-%{release}
Requires:       glib2-devel

%description gobject-devel
%{name}-gobject contains GObject bindings for %{name}.

This package is needed if you want to write software using the
GObject bindings.  It also contains GObject Introspection information.

%package rescue
Summary:        Virt-rescue shell
BuildRequires:  iputils
BuildRequires:  lsof
BuildRequires:  pciutils
BuildRequires:  strace
BuildRequires:  vim

%description rescue
This adds the virt-rescue shell which is a "rescue disk" for virtual
machines, and additional tools to use inside the shell such as ssh,
network utilities, editors and debugging utilities.

%package rsync
Summary:        Rsync support for %{name}
Requires:       %{name} = %{version}-%{release}
BuildRequires:  rsync

%description rsync
This adds rsync support to %{name}.  Install it if you want to use
rsync to upload or download files into disk images.

%package xfs
Summary:        XFS support for %{name}
Requires:       %{name} = %{version}-%{release}

%description xfs
This adds XFS support to %{name}.  Install it if you want to process
disk images containing XFS.

%package man-pages-ja
Summary:        Japanese (ja) man pages for %{name}
BuildArch:      noarch
Requires:       %{name} = %{version}-%{release}

%description man-pages-ja
%{name}-man-pages-ja contains Japanese (ja) man pages
for %{name}.

%package man-pages-uk
Summary:        Ukrainian (uk) man pages for %{name}
BuildArch:      noarch
Requires:       %{name} = %{version}-%{release}

%description man-pages-uk
%{name}-man-pages-uk contains Ukrainian (uk) man pages
for %{name}.

%post -n %{name} -p /sbin/ldconfig
%postun -n %{name} -p /sbin/ldconfig
%post -n libguestfs0 -p /sbin/ldconfig
%postun -n libguestfs0 -p /sbin/ldconfig
%post -n %{name}-gobject-1_0 -p /sbin/ldconfig
%postun -n %{name}-gobject-1_0 -p /sbin/ldconfig

%files -f %{name}.lang
%license README COPYING
%{_bindir}/guestfish
%{_bindir}/guestmount
%{_bindir}/guestunmount
%{_bindir}/libguestfs-test-tool
%{_bindir}/virt-copy-in
%{_bindir}/virt-copy-out
%{_bindir}/virt-tar-in
%{_bindir}/virt-tar-out
%{_mandir}/man1/guestfish.1*
%{_mandir}/man1/guestfs-faq.1*
%{_mandir}/man1/guestfs-performance.1*
%{_mandir}/man1/guestfs-recipes.1*
%{_mandir}/man1/guestfs-release-notes.1.gz
%{_mandir}/man1/guestfs-release-notes-1*.1*
%{_mandir}/man1/guestfs-security.1*
%{_mandir}/man1/guestmount.1*
%{_mandir}/man1/guestunmount.1*
%{_mandir}/man1/libguestfs-test-tool.1*
%{_mandir}/man1/virt-copy-in.1*
%{_mandir}/man1/virt-copy-out.1*
%{_mandir}/man1/virt-tar-in.1*
%{_mandir}/man1/virt-tar-out.1*
%{_mandir}/man5/libguestfs-tools.conf.5*
%config %{_sysconfdir}/profile.d/guestfish.sh
%config(noreplace) %{_sysconfdir}/libguestfs-tools.conf

%files -n libguestfs0
%license COPYING.LIB
%{_libdir}/libguestfs.so.*

%files -n libguestfs-appliance
%dir %{_libdir}/guestfs
%dir %{_libdir}/guestfs/supermin.d
%{_libdir}/guestfs/supermin.d/base.tar.gz
%{_libdir}/guestfs/supermin.d/daemon.tar.gz
%{_libdir}/guestfs/supermin.d/init.tar.gz
%{_libdir}/guestfs/supermin.d/udev-rules.tar.gz
%{_libdir}/guestfs/supermin.d/excludefiles
%{_libdir}/guestfs/supermin.d/hostfiles
%{_libdir}/guestfs/supermin.d/packages
%{_libdir}/guestfs/supermin.d/zz-scripts.tar.gz

%files winsupport
%{_libdir}/guestfs/supermin.d/zz-*winsupport*

%files bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/guestfish
%{_datadir}/bash-completion/completions/guestmount
%{_datadir}/bash-completion/completions/guestunmount
%{_datadir}/bash-completion/completions/libguestfs-test-tool
%{_datadir}/bash-completion/completions/virt-copy-in
%{_datadir}/bash-completion/completions/virt-copy-out
%{_datadir}/bash-completion/completions/virt-rescue
%{_datadir}/bash-completion/completions/virt-tar-in
%{_datadir}/bash-completion/completions/virt-tar-out

%files inspect-icons
# no files

%files -n ocaml-%{name} -f %name.files

%files -n ocaml-%{name}-devel -f %name.files.devel
%doc ocaml/examples/*.ml ocaml/html
%{_mandir}/man3/guestfs-ocaml.3*

%files -n perl-Sys-Guestfs
%{perl_vendorarch}/*
%doc perl/examples/*.pl
%{_mandir}/man3/Sys::Guestfs.3pm*
%{_mandir}/man3/guestfs-perl.3*

%files -n python3-%{name}
%doc python/examples/*.py
%{python3_sitearch}/libguestfsmod*.so
%{python3_sitearch}/guestfs.py
%{_mandir}/man3/guestfs-python.3*

%files -n rubygem-%{name}
%doc ruby/examples/*.rb
%doc ruby/doc/site/*
%{_libdir}/ruby
%{_mandir}/man3/guestfs-ruby.3*

%files -n lua-%{name}
%doc lua/examples/*.lua
%doc lua/examples/LICENSE
%{_libdir}/lua
%{_mandir}/man3/guestfs-lua.3*

%files gobject-1_0
%{_libdir}/libguestfs-gobject-1.0.so.0*

%files typelib-Guestfs-1_0
%{_libdir}/girepository-1.0/Guestfs-1.0.typelib

%files gobject-devel
%{_libdir}/libguestfs-gobject-1.0.so
%{_includedir}/guestfs-gobject.h
%dir %{_includedir}/guestfs-gobject
%{_includedir}/guestfs-gobject/*.h
%{_datadir}/gir-1.0/Guestfs-1.0.gir
%{_libdir}/pkgconfig/libguestfs-gobject-1.0.pc
%{_mandir}/man3/guestfs-gobject.3*

%files devel
%doc examples/*.c
%{_sbindir}/libguestfs-make-fixed-appliance
%{_libdir}/*.so
%{_libdir}/pkgconfig/libguestfs.pc
%{_includedir}/guestfs.h
%{_mandir}/man1/guestfs-building.1*
%{_mandir}/man1/guestfs-hacking.1*
%{_mandir}/man1/guestfs-internals.1*
%{_mandir}/man1/guestfs-testing.1*
%{_mandir}/man1/libguestfs-make-fixed-appliance.1*
%{_mandir}/man3/guestfs.3*
%{_mandir}/man3/guestfs-examples.3*
%{_mandir}/man3/libguestfs.3*

%files -n libguestfsd
%{_udevrulesdir}
%{_sbindir}/guestfsd
%{_mandir}/man8/*

%files rescue
%{_libdir}/guestfs/supermin.d/zz-packages-rescue
%{_bindir}/virt-rescue
%{_mandir}/man1/virt-rescue.1*

%files rsync
%{_libdir}/guestfs/supermin.d/zz-packages-rsync

%files xfs
%{_libdir}/guestfs/supermin.d/zz-packages-xfs

%files man-pages-ja
%lang(ja) %{_mandir}/ja/man1/*.1*
%lang(ja) %{_mandir}/ja/man3/*.3*
%lang(ja) %{_mandir}/ja/man5/*.5*

%files man-pages-uk
%if 0%{?suse_version} <= 1500
%dir %{_mandir}/uk
%dir %{_mandir}/uk/man{1,3,5}
%endif
%lang(uk) %{_mandir}/uk/man1/*.1*
%lang(uk) %{_mandir}/uk/man3/*.3*
%lang(uk) %{_mandir}/uk/man5/*.5*

%changelog
* Thu Jan 30 2025 carnold@suse.com
- Update to version 1.55.3 (jsc#PED-8910)
  * build: Move baseline OCaml to 4.08
  * Various translation updates
* Fri Jan  3 2025 carnold@suse.com
- Update to version 1.55.2 (jsc#PED-8910)
  * lib/inspect-osinfo.c: Add Windows Server 2025 osinfo
  * appliance: Use stable owner, group and mtime in appliance
    tarballs
  * mltools: Replace jansson with json-c
  * lib/info.c: Replace jansson with json-c
  * lib/qemu.c: Replace jansson with json-c
  * lib: direct: Remove test for qemu mandatory locking
  * Various language translations
  * Fix dhcpcd failing on systemd-resolved stub
  * mlcustomize: Add heuristic support for Windows Server 2025
  * mlcustomize/customize_run.ml: Move 'in' to new line
  * mlstdutils/guestfs_config: Define host_os
  * mlcustomize, mltools: Check guest OS is compatible before
    allowing --run
  * generator: Remove common/mlv2v/uefi.ml{,i} files
  * qemuopts: Add ability to add raw, unquoted output to qemu
    scripts
  * qemuopts: Fix missing break statement
  * mlstdutils: Remove Option module
  * Remove test for caml_alloc_initialized_string
  * build: Move baseline OCaml to 4.08
* Thu Oct 10 2024 carnold@suse.com
- Update to version 1.54.0 (jsc#PED-8910)
  * Add detection of Circle Linux (Bella Zhang).
  * Add support for LoongArch (liuxiang).
  * Add detection of Kylin (grass-lu).
  * Add detection of openEuler (Wang Guoquan).
  * PARTUUID and PARTLABEL are now resolved in guest /etc/fstab.
  * New APIs findfs_partuuid and findfs_partlabel. These can be
    used to efficiently look up a filesystem by its GPT partition
    UUID or label.
  * Support for the following inactive or infrequently used device
    types has been removed: Gluster, Sheepdog, TFTP.
  * Add GOST R34.11-94 message digest algorithm to checksum APIs
    (Alexey Shabalin).
  * Allow nbd+unix:// URIs (NBD over Unix domain socket) in
    guestfish and other places.
  * Various part_* (partition) APIs related to GPT have been
    reimplemented to use util-linux sfdisk instead of sgdisk.
    Util-linux is more widely available, so this reduces
    dependencies in the common case. One optional API remains that
    still uses sgdisk. (Thanks Yongkui Guo).
  * Add cipher suboption to cryptsetup_open (Jonatan Pålsson).
  * Because of a bug, the part_get_gpt_attributes API could
    truncate the return value from 64 to 32 bits. This has been
    fixed.
  * Libguestfs will now no longer recommend using
    LIBGUESTFS_BACKEND=direct. This was shown previously when
    libvirt failed to start the appliance. However it is felt that
    this now does more harm than good.
  * Fix generation of virt-customize --chown parameter (Yongkui Guo)
  * In the appliance, reduce boot time when dhcp isn't needed
    (Olaf Hering).
  * A deadlock in the appliance caused by a regression in Linux
    6.11 has been worked around. The deadlock was also fixed in
    Linux 6.12.
- Bug fixes
  * Fix rare hangs while starting the appliance, at 'echo noop'
    into /sys/block/{h,s,ub,v}d*/queue/scheduler
  * Drop dependency from libguestfs -> gdisk
  * libguestfs inspection does not know about /etc/fstab
    PARTLABEL=<label>
  * btrfs related c_api/tests are failing (unable to create quota
    group: Invalid argument)
  * Python how-to incorrect exception name
  * Rust test 410_close_event fails
* Thu Aug 29 2024 carnold@suse.com
- Update to version 1.53.6 (jsc#PED-8910)
  * Various MacOS fixes and enhancements
  * ocaml: INSTALL_OCAMLLIB Makefile parameter
  * appliance/init: Don't set impossible "noop" disk scheduler
  * Pull in some fixes from the common submodule.
    mlcustomize: Add Inject_virtio_win.inject_blnsvr implementation
    mlcustomize: firstboot: Use Linux path for Powershell script path
    mlcustomize: firstboot: Use powershell.exe instead of path
    mlcustomize: firstboot: Use Powershell -NoProfile flag
    mlcustomize: Revert delay installation of qemu-ga MSI
    mldrivers/linux_kernels.ml: Prefix general information with ^info:
    mlcustomize: Use Start-Process -Wait to run qemu-ga installer
    mlcustomize: Add Firstboot.firstboot_dir function
    mlcustomize: Place powershell scripts into <firstboot_dir>\Temp
    mlcustomize: Inject qemu-ga & blnsvr into <firstboot_dir>/Temp
    mlcustomize: Write qemu-ga log file name to log.txt
    mlcustomize: Add some comments to firstboot batch file
    mlcustomize: Reboot Windows between each firstboot script
* Tue Jul 16 2024 carnold@suse.com
- Update to version 1.53.5 (jsc#PED-6305)
  * generator/customize.ml: Split --chown parameter on ':' character
  * daemon: Add gost checksum command support
  * Add detection support for Circle Linux
  * Add support for LoongArch.
  * daemon: Fix file architecture translation for LoongArch
  * options: Allow nbd+unix:// URIs
  * daemon/parted: Assume sfdisk --part-type exists
  * daemon: Reimplement partition GPT functions using sfdisk
  * appliance: only wait for resolv.conf update if dhcpcd succeeded
  * generator/customize.ml: Add virt-customize --inject-blnsvr operation
  * lib: libvirt: Stop recommending LIBGUESTFS_BACKEND=direct
  * daemon: cryptsetup_open: Add --cipher
  * rust: Handle null pointer when creating slice
  * Remove gluster support
  * Remove sheepdog support
  * Remove tftp drive support
  * generator/daemon: Don't truncate 64 bit results from OCaml functions
  * daemon: Fix parsing in part_get_gpt_attributes
  * New APIs: findfs_partuuid and findfs_partlabel
  * inspection: Resolve PARTUUID= and PARTLABEL= in /etc/fstab
  * generator/actions_core.ml: Fix version field for new APIs
  * Kylin is centos derivative
* Thu May 16 2024 carnold@suse.com
- Update to version 1.52.1 bug fix release (jsc#PED-6305)
  * There are no upstream release notes for verion 1.52.x
  * Several python fixes
  * Rework Std_utils.Option so it works like the OCaml stdlib module
  * Update common submodule to latest
- Drop patches contained in new tarball
  Split-chown-parameter-on-character.patch
  Initialise-bar-fp-as-NULL.patch
* Wed May  8 2024 carnold@suse.com
- Set Recommends on zerofree and ntfsprogs for libguestfs-appliance
  (bsc#1223444)
* Tue May  7 2024 carnold@suse.com
- Switch Recommends to Requires for several packages in the
  libguestfs-appliance which is where the tools from these
  packages are used. (bsc#1223444)
* Mon Apr 15 2024 carnold@suse.com
- Require ntfs-3g for libguestfs-winsupport
  libguestfs.spec
* Fri Mar 29 2024 carnold@suse.com
- Upstream bug fixes
  Split-chown-parameter-on-character.patch
  Initialise-bar-fp-as-NULL.patch
* Mon Feb  5 2024 carnold@suse.com
- bsc#1206361 - SLES 15 SP5 Beta2 - virt-customize ssh-inject fails
  (s390x/kvm/libvirt) (-> Server-Applications module)
  use-rtc-driftfix-slew-for-x86-only.patch
* Wed Jan 31 2024 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(libzstd) additionaly to zstd: we need the
  devel package. In the past, it was pulled in by indirect deps.
* Thu Jan 11 2024 carnold@suse.com
- Copy sorted packagelist to packages during supermin appliance
  setup. (bsc#1215586)
  libguestfs.spec
* Thu Jan  4 2024 carnold@suse.com
- Update to version 1.52.0 (jsc#PED-6305)
  * The Python bindings now use bytes (instead of str) for the
    event callback message, since it may contain arbitrary 8 bit
    data
    Fix a rare crash, and avoid memory leaks in event callbacks
  * Support for OCaml 5, and OCaml ≥ 4.07 is now the minimum
  * The OCaml bindings now release the runtime lock around calls
    to guestfs_close, since that call might be long-running (for
    example it might have to shut down the appliance and synch disks).
  * Support OpencloudOS
  * SELinux relabelling now runs in parallel, meaning it's a lot
    quicker
  * Add support for lzma and zstd compression methods in tar APIs
    (like guestfs_tar_in)
  * guestfs_pvs_full previously didn't always return the correct
    device names. This has now been fixed.
  * guestfs_btrfs_filesystem_balance fixed so it now works with
    more modern btrfs tools (Jürgen Hötzel).
  * The guestfish(1) --key option now recognizes LVM names like
    /dev/mapper/rhel_bootp--73--75--123-root
  * guestfish --key option also supports a new --key all:...
    selector to try the same key on all devices.
  * In guestmount(1) avoid calling fclose(NULL) on error paths,
    which might have caused a crash on some platforms.
* Tue Dec 19 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Provide a tar-wrapper that creates bit-reproducible output (boo#1218191)
* Tue Dec 12 2023 ohering@suse.de
- Use ocaml-rpm-macros to track OCaml ABI
- Remove unused perl_gen_filelist
* Mon Dec 11 2023 carnold@suse.com
- Update to version 1.51.9
  * Include <libxml/parser.h> for xmlReadMemory
  * Language translations
* Thu Nov 30 2023 olaf@aepfle.de
- Require OCaml 4.07+
* Tue Nov 28 2023 carnold@suse.com
- Update to version 1.51.8
  * There are no upstream release notes for verion 1.51.x
  * Dropped the virt-dib tool
  * Add support for lzma and zstd compression methods.
  * Add --chown option for virt-customize
  * Add new virt-customize --tar-in operation
  * Various bug fixes and language translations
- Drop patch contained in new tarball
  Omit-file--S-option-on-older-distros-that-lack-support.patch
* Mon Sep 25 2023 carnold@suse.com
- bsc#1215543 - guestfs regression: file: Use -S option with -z
  Omit-file--S-option-on-older-distros-that-lack-support.patch
  See also bsc#1215461
- bsc#1215586 - guestfs regression: non functional network due to
  missing sysconfig-netconfig
  libguestfs.spec
* Wed Jul  5 2023 carnold@suse.com
- bsc#1212972 - cannot find any suitable libguestfs supermin
  libguestfs.spec (see also bsc#1215664)
* Thu Mar 23 2023 Martin Liška <mliska@suse.cz>
- Enable LTO as it works fine now (use FAT lto objects for static libs).
* Wed Mar 15 2023 Vasily Ulyanov <vasily.ulyanov@suse.com>
- bsc#1213243 - KubeVirt needs libguestfs with the support of qcow2
  appliances
- Configure with --enable-appliance-format-auto to allow
  qcow2-format fixed appliances.
* Wed Feb 22 2023 carnold@suse.com
- Update to version 1.50.1
  * This is a bug fix release. No upstream changelog.
* Thu Feb  9 2023 carnold@suse.com
- Update to version 1.50.0
  * https://libguestfs.org/guestfs-release-notes-1.50.1.html
  * Inspection
    When listing the packages in RPM-based guests, the inspection
    API no longer checks package signatures. This is because the
    newer librpm used by libguestfs does not understand signatures
    stored in older guests, such as SHA1 used by RHEL 6 (thanks
    Panu Matilainen).
    "guestfs_inspect_get_hostname" in guestfs(3) can now handle
    /etc/hostname files containing comments (thanks Dawid Zamirski).
    "guestfs_file_architecture" in guestfs(3) can now parse files
    using zstd compression.
    "guestfs_inspect_get_osinfo" in guestfs(3) now returns the
    correct osinfo field for Windows 11. However because of
    decisions made by Microsoft, these guests still return product
    name and other strings identifying as Windows 10 (thanks Yaakov
    Selkowitz, Yongkui Guo).
  * New APIs
    "guestfs_device_name" in guestfs(3) is a new API to read the
    device name associated with a drive, for example calling this
    with 0 will return /dev/sda.
    "guestfs_clevis_luks_unlock" in guestfs(3) is a new API for
    unlocking disks using the Clevis/Tang network-based full disk
    encryption scheme. Furthermore implement this in guestfish and
    guestmount (Laszlo Ersek).
    "guestfs_inspect_get_build_id" in guestfs(3) is a new API for
    reading the build ID from some Linux and Windows guests. It is
    not widely used on Linux, but for Windows it is vital for
    identifying Windows 11.
  * Other API changes
    In the "guestfs_add_drive" in guestfs(3) API, the name and
    iface fields are not used. name has not been used since around
    2017, but the documentation has only just been updated to reflect
    this. iface was never allowed for the libvirt backend and
    didn't work reliably with the direct backend (Laszlo Ersek).
    "guestfs_readdir" in guestfs(3) is no longer limited to the
    maximum message size but can read a directory of any size
    (Laszlo Ersek).
  * Numerous build changes, internal improvements, and bug fixes
    Note that the Augeas bindings for libguestfs are no longer
    bundled with libguestfs and must be built separately.
* Fri Dec 16 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.18: rpm wants to do a proper cleanup, and
  fails on the design choice to have /usr/lib64 without write
  permission. As we already tar'ed the content up, we can simply
  change the permissions of winsupport's content to allow proper
  erasing.
* Wed Nov 30 2022 Andreas Schwab <schwab@suse.de>
- Enable build on riscv64
* Tue Nov 29 2022 carnold@suse.com
- Update to version 1.48.6
  * jsc#PED-2113
  * This is a bug fix release. No upstream changelog.
- Drop f162e47e-m4-Fix-configure-disable-ocaml.patch
* Thu Oct 20 2022 Ludwig Nussel <lnussel@suse.de>
- Drop reiserfs (boo#1191092)
* Fri Oct 14 2022 carnold@suse.com
- Drop requirement for icoutils in SLE as this package is not
  available.
  libguestfs.spec
* Tue Oct  4 2022 carnold@suse.com
- jsc#PED-2113 [Virt Tools] Refresh Virtualization Tools for Xen
  and KVM Management
* Tue Sep  6 2022 carnold@suse.com
- Upstream patch to fix running configure --disable-ocaml
  f162e47e-m4-Fix-configure-disable-ocaml.patch
* Tue Jul 12 2022 carnold@suse.com
- Update to version 1.48.4
  * This is a bug fix release
- Drop patches included in new tarball
  CVE-2022-2211-docs-guestfs-security-document.patch
  CVE-2022-2211-options-fix-buffer-overflow-in-get_keys.patch
* Wed Jun 29 2022 carnold@suse.com
- bsc#1201064 - Libguestfs: Buffer overflow in get_keys leads
  to DOS - CVE-2022-2211
  CVE-2022-2211-options-fix-buffer-overflow-in-get_keys.patch
  CVE-2022-2211-docs-guestfs-security-document.patch
* Fri Jun  3 2022 carnold@suse.com
- bsc#1190501 - virt-builder fails to install packages when
  building an image. Add Recommends: dhcp-client for the appliance.
  libguestfs.spec
* Wed Jun  1 2022 carnold@suse.com
- Update to version 1.48.3
  * Several bugs fixed in this release since version 1.48.1
  * Updated language files
* Mon Apr 18 2022 carnold@suse.com
- Update to version 1.48.1
  * Updated language files
  * A few bug fixes in this release
  * Drop requirement for newer ocaml required by Bytes.get_uint8.
    It is replaced with a local implementation.
* Wed Apr 13 2022 Hans-Peter Jansen <hpj@urpla.net>
- Add relevant %%post{,un} sections
- Add another rpmlint filter
- Add uk man dirs
* Wed Apr 13 2022 Hans-Peter Jansen <hpj@urpla.net>
- Avoid useless builds, if ocaml version isn't up to the task
  libguestfs uses get_uint8(), available since ocaml 4.13.0
* Thu Mar 17 2022 carnold@suse.com
- Update to version 1.48.0
  * Fix allocation and deallocation of string lists in golang
    bindings (Laszlo Ersek).
  * Multiple fixes to the OCaml bindings:
  * Add support for Kylin (Laszlo Ersek).
  * Add support for Rocky Linux (Neil Hanlon).
  * Inspection of guests which use LUKS encryption on top of LVM
    logical volumes should now work (Laszlo Ersek).
  * "guestfs_list_9p" and "guestfs_mount_9p" are deprecated and
    now return errors.
  * "guestfs_remove_drive" has been deprecated and now returns an
    error.
  * "guestfs_add_drive" no longer supports hotplugging
  * In "guestfs_xfs_admin" the "lazycounter" parameter is deprecated
    because it is no longer supported in recent versions of XFS.
  * The User-mode Linux ("uml") backend has been removed.
  * Partition APIs now cope with the broken MBR partition tables
    created by dosfstools ≥ 4.2 (Laszlo Ersek).
  * Various bug fixes
* Wed Feb 16 2022 carnold@suse.com
- Update to version 1.46.2
  * This release has moved many virt tools like virt-builder,
    virt-cat, virt-customize, virt-df, etc. to the guestfs-tools
    project. This makes libguestfs a bit easier to build and manage.
  * The build now uses and requires PCRE2 (instead of PCRE).
  * This version requires libvirt ≥ 7.1.0, if libvirt is enabled.
  * gnulib is no longer bundled with libguestfs, making builds from
    git much simpler.
  * Perl Sys::Virt (libvirt bindings for Perl) are no longer
    required by libguestfs.
  * The code has been compiled with both LTO and GCC -fanalyzer and
    many bugs and warnings fixed.
  * Various fixes for qemu 6.1.
  * Update appliance packages on SUSE and several other improvements
    to the init script (Olaf Hering).
  * We now use the qemu / libvirt feature -cpu max to select the
    best CPU to run the appliance.
  * When passing the appliance filesystem UUID to supermin we now
    read it directly out of the appliance instead of using the
    file(1) program. This is more reliable.
  * The qemu -enable-fips option is no longer used. It was not
    needed and has been deprecated by qemu.
  * We no longer use qemu's sga (Serial Graphics Adapter) option
    ROM, instead using the equivalent seabios feature.
  * Various bug fixes
- Package changes
  * New libguestfs.spec file.
  * Moved guestfs-tools to a new and separate project and package
  * Renamed packages
    guestfs-winsupport -> libguestfs-winsupport
    guestfsd -> libguestfsd
  * New packages
    libguestfs, libguestfs-typelib-Guestfs,
    libguestfs-gobject, libguestfs-gobject-devel
    libguestfs-rescue, libguestfs-rsync, libguestfs-xfs
  * Dropped package libguestfs-test
- Dropped scripts and patches
  Pod-Simple-3.23.tar.xz
  libguestfs.test.simple.create-opensuse-guest-crypt-on-lvm.sh
  libguestfs.test.simple.create-opensuse-guest.sh
  libguestfs.test.simple.create-sles12-guest-crypt-on-lvm.sh
  libguestfs.test.simple.create-sles12-guest.sh
  libguestfs.test.simple.run-libugestfs-test-tool.sh
  0001-Introduce-a-wrapper-around-xmlParseURI.patch
  0002-common-extract-UTF-8-conversion-function.patch
  0003-inspector-rpm-summary-and-description-may-not-be-utf.patch
  489b14b7-ocaml-examples-Link-examples-to-gnulib.patch
  63c9cd93-m4-guestfs-ocaml.m4-Fix-deprecated-warning-format.patch
  68a02c2f-customize--resize--sparsify--sysprep-Link-explicitly-with-pthread.patch
  9db0c98c-appliance-enable-bashs-Process-Substitution-feature.patch
  a4930f5f-customize-Suppress-OCaml-warning.patch
  c0de4de9-appliance-add-reboot-and-netconfig-for-SUSE.patch
  e26cfa44-daemon-Build-with--pthread.patch
  f47e0bb6-appliance-reorder-mounting-of-special-filesystems-in-init.patch
  appliance.patch
  libguestfs.env.patch
  makefile-ocaml-find-guestfs.patch
  netconfig.patch
* Mon Feb  7 2022 carnold@suse.com
- bsc#1195415 - libguestfs: consider dropping build requirement on
  systemd-sysvinit
  libguestfs.spec
* Tue Dec 14 2021 ohering@suse.de
- Add python-rpm-macros (bsc#1180125)
* Tue Oct 26 2021 carnold@suse.com
- Fix build errors in Factory
  * Alert ocaml_deprecated_cli: Setting a warning with a sequence
    of lowercase or uppercase letters, like 'CDEFLMPSUVYZX', is
    deprecated.
  63c9cd93-m4-guestfs-ocaml.m4-Fix-deprecated-warning-format.patch
  * Error (warning 6 [labels-omitted]): label verbose was omitted
    in the application of this function.
  a4930f5f-customize-Suppress-OCaml-warning.patch
* Tue Oct  5 2021 carnold@suse.com
- Update spec file licenses to GPL-2.0-or-later
* Wed Sep 15 2021 carnold@suse.com
- bsc#1190501 - virt-builder fails to install packages when
  building an image
  9db0c98c-appliance-enable-bashs-Process-Substitution-feature.patch
- Upstream bug fixes
  c0de4de9-appliance-add-reboot-and-netconfig-for-SUSE.patch
  f47e0bb6-appliance-reorder-mounting-of-special-filesystems-in-init.patch
* Mon Sep 13 2021 carnold@suse.com
- Newer cpio versions must be told to extract over symlinks
  libguestfs.test.simple.create-opensuse-guest-crypt-on-lvm.sh
  libguestfs.test.simple.create-opensuse-guest.sh
  libguestfs.test.simple.create-sles12-guest-crypt-on-lvm.sh
  libguestfs.test.simple.create-sles12-guest.sh
- Allow the use busybox dhcp client
  appliance.patch
  netconfig.patch
* Mon Sep 13 2021 carnold@suse.com
- Update to version 1.44.2
  makefile-ocaml-find-guestfs.patch
  * Port libguestfs to use pcre2 instead of pcre
  * inspection: More reliable detection of Linux split /usr configurations
  * python: Relicense setup.py to LGPLv2+ (originally GPLv2+)
  * lib: qemu: Don't use -enable-fips option.
  * rust: Fix deprecated use of panic!(format!(...))
  * point users to Libera Chat rather than FreeNode
  * python: Don't leak fields when creating Python structs
  * appliance: Add IBM850 iconv converter for syslinux
  * launch: board model for RISC-V
  * lib: Add osinfo information for Windows Server 2022 Datacenter
  * lib: Autodetect backing format for qemu-img create -b
  * appliance: Fix searching for shared libraries on usr-merged Debian systems
  * appliance: Add mount package for Debian
  * m4/guestfs-appliance.m4: Add support for Alma and Cloud Linux
  * daemon/luks.c: Ignore bogus GCC -fanalyzer double-free warning
  * daemon/xattr.c: Increase size of temporary buffer for %%zu
  * daemon/utils.c: Fix potential unbounded stack usage
  * Various other bug fixes
- Upstream bug fixes post 1.44.2
  e26cfa44-daemon-Build-with--pthread.patch
  489b14b7-ocaml-examples-Link-examples-to-gnulib.patch
  68a02c2f-customize--resize--sparsify--sysprep-Link-explicitly-with-pthread.patch
* Sun Jul 18 2021 ohering@suse.de
- Remove obsolete yajl
- Add conditional to ocaml_preserve_bytecode
- Remove traces of python2 code
- Use pkgconfig(python3) to refer to variants of python3
- Remove obsolete 0004-python-include-dirs.patch and related
  workaround in spec file
- Use autosetup
- Use _udevrulesdir
- Remove BuildRoot and defattr
- Remove Group tags
* Fri May 28 2021 ohering@suse.de
- For unknown reasons the appliance build fails randomly
  Workaround it by retrying the build once
* Tue Apr 13 2021 ohering@suse.de
- Update to version 1.44.1
  * lib/appliance-kcmdline.c: Read UUID directly from appliance.
  * daemon/xfs.c: Fix error message.
  * daemon: chroot: Fix long-standing possible deadlock.
  * daemon: Don't return bogus failure from readdir.
  * daemon/btrfs.c: Ignore mkfs.btrfs allocstart option.
  * python: Ignore code style error E128.
  * php: Fix the build.
  * builder: Don't redefine Val_none (OCaml 4.12).
  * daemon: lvm: Use lvcreate --yes to avoid interactive prompts.
  * Update common submodule.
  * lib/fuse.c: Use safe_malloc instead of malloc.
  * fuse/guestmount.c: Avoid leaking fp on error path.
  * diff: Don't try to call unlink(NULL) on certain error paths.
  * daemon/tar.c: Avoid bogus GCC analyzer warning.
  * daemon/command.c daemon/debug.c df/main.c: Ignore bogus GCC analyzer warnings
  * appliance: Add dhclient for Arch-like Manjaro distro.
  * fish/tilde.c: Suppress more bogus -fanalyser warnings.
  * lib/qemu.c: Suppress another bogus -fanalyser warning.
  * builder: templates: Add ubuntu-20.04.
  * builder: templates: Added rhel-7.9.
  * lib: Move CLEANUP_GL_RECURSIVE_LOCK_UNLOCK to libguestfs header.
  * appliance: Avoid having ${exec_prefix} in guestfs appliance path.
  * build: Avoid warnings about unknown pragmas.
- add libguestfs.env.patch
- Remove ocaml_native_compiler conditional
  build native target unconditionally
* Fri Apr  9 2021 ohering@suse.de
- Require current ocaml-rpm-macros
* Tue Jan 12 2021 carnold@suse.com
- Modify Source0 to point at the correct url for the source.
  libguestfs.spec
* Mon Jan 11 2021 carnold@suse.com
- Update to version 1.44.0
  * The minimum version of Python required is 3.6.
  * Python bindings no longer use deprecated
    "PyEval_ThreadsInitialized".
  * Python bindings now include type hints (Sam Eiderman).
  * Erlang bindings now use libei instead of liberl_interface
    (Sergei Golovan).
  * virt-get-kernel(1) can now find uncompressed kernels
    (Pino Toscano).
  * virt-sysprep(1) now regenerates the guest certificate store
    when a certificate is removed from the guest (Pino Toscano).
  * virt-sysprep(1) can now remove IPA enrollment files and
    Kerberos keytabs
    (Pino Toscano, Christian Heimes and François Cami).
  * "cryptsetup-open" and "cryptsetup-close" replace "luks-open",
    luks-open-ro and luks-close. The new APIs add support for
    BitLocker encryption.
  * "lvm-canonical-lv" no longer produces a noisy error message
    when called with a non-LV parameter.
  * Various other bug fixes
- Drop
  bfd08867-golang-Fix-path-to-include-guestfs.h..patch
  dbfab7d3-build-fix-includedir-in-uninstalled-libguestfs.pc.patch
* Thu Nov  5 2020 carnold@suse.com
- bsc#1178495 - Leap Gap: Libguestfs.spec contains the is_opensuse
  macro
  libguestfs.spec
* Tue Oct 20 2020 carnold@suse.com
- Drop is_opensuse references to remove differences between Leap
  and SLES packaging
  libguestfs.spec
* Tue Oct  6 2020 carnold@suse.com
- Update to version 1.43.2
  * Bug fix release
  * Updated language files
  0004-python-include-dirs.patch
- Added upstream bug fixes
  dbfab7d3-build-fix-includedir-in-uninstalled-libguestfs.pc.patch
  bfd08867-golang-Fix-path-to-include-guestfs.h..patch
* Mon Jul 20 2020 carnold@suse.com
- Update to version 1.43.1
  * Drop support for python 2
  * builder: New templates added
  * sysprep: ca-certificates: request system CA store update
  * Various other bug fixes
- Drop
  31e6b187-po-Remove-virt-v2v-related-dependency-from-POTFILES-ml..patch
  7265f08c-lib-remove-extra-LIBS-from-pkg-config-file.patch
* Tue Jul  7 2020 carnold@suse.com
- bsc#1172818 - libguestfs: inconsistent LIBGUESTFS_PATH
  libguestfs.spec
* Wed Apr 22 2020 carnold@suse.com
- Update to version 1.42.0
  * virt-v2v is moved out from libguestfs into its own package
  * virt-p2v is moved out from libguestfs into its own package
  * Add support for the Vala language
  * Add support for the Rust language
  * Reproducible builds
  * Advanced Format disks (which use 4K sectors) can now be
    processed by libguestfs. Use the new optional blocksize
    parameter to guestfs_add_drive_opts, and the --blocksize option
    added to several tools
  * Windows CompactOS (NTFS file compression) is now supported.
  * Advanced machine readable output in various virt tools now
    supports JSON output, and writing logs to a numbered file
    descriptor
  * virt-filesystems tool now more accurately reports filesystem
    total size, in the case where for example the filesystem does
    not occupy the whole of its containing device
  * Python ≥ 2.7 is required.
  * Python bindings are now more extensively tested
  * Python bindings should now work with Python ≥ 3.8.
  * Multiple fixes to avoid crashes in the Python bindings
  * OCaml bindings are compiled with -DCAML_NAME_SPACE to ensure no
    non-caml_-namespaced symbols are used
  * OCaml bindings should now work with OCaml 4.09 and 4.10.
  * Fix compatibility with newer cgo for Go bindings
  * Go API error handling is now more idiomatic
  * Update documentation about how to handle boolean parameters in
    Ruby bindings
  * Libguestfs can now extract icons for Gentoo, newer SUSE and
    OpenMandriva guests. Improved extraction of RHEL icons.
  * Inspection returns the osinfo IDs of newer Windows versions,
    and rolling Linux distros
- Added patches
  31e6b187-po-Remove-virt-v2v-related-dependency-from-POTFILES-ml..patch
  7265f08c-lib-remove-extra-LIBS-from-pkg-config-file.patch
- Patches dropped
  0a55098f-builder-repository-fix-compute_short_id-for-sles-X.0.patch
  28bd06227b-inspect-handle-os-release-opensuse-tumbleweed-as-ope.patch
  500acb15-v2v-linux-fix-kernel-detection-when-split-in-different-packages.patch
  70407cd622-inspection-Parse-os-release-opensuse-leap-as-opensus.patch
  d0e5a819-python-Fix-missing-additional-backslashes.patch
  fd43730e-error-with-uninstall-option-on-SUSE.patch
* Thu Mar 19 2020 carnold@suse.com
- bsc#1167131 - virt-v2v fails importing ubuntu 18.04 LTS ova
  500acb15-v2v-linux-fix-kernel-detection-when-split-in-different-packages.patch
* Tue Sep 10 2019 Christophe Giboudeaux <christophe@krop.fr>
- Use -ffat-lto-objects when building static libraries.
* Mon Sep  9 2019 Larry Dewey <ldewey@suse.com>
- Added lvm2 to Requires for using virt-resize of xfs images.
  (bsc#1138860)
* Wed Aug 28 2019 Guilherme Moro <gmoro@suse.com>
- Add sysconfig-netconfig to appliance (boo#1136878)
  Patches added:
    netconfig.patch
* Thu Aug 22 2019 ohering@suse.de
- Remove empty /etc/libguestfs-tools.conf
* Wed Jun 12 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut the build queues by allowing usage of systemd-mini
* Wed Apr 17 2019 Larry Dewey <ldewey@suse.com>
- Fixing issue with virt-customize in SLES and openSUSE guests
  (boo#1132790)
  Patches added:
    28bd06227b-inspect-handle-os-release-opensuse-tumbleweed-as-ope.patch
    70407cd622-inspection-Parse-os-release-opensuse-leap-as-opensus.patch
* Mon Apr  8 2019 Larry Dewey <ldewey@suse.com>
- Fixing issue with virt-customize uninstall and '-l'
  (bnc#1131342)
  Patches added:
    fd43730e-error-with-uninstall-option-on-SUSE.patch
* Mon Jun 11 2018 ohering@suse.de
- Remove zerofree from BuildRequires because only supermin will
  consider this feature at runtime.
* Thu Apr 19 2018 cbosdonnat@suse.com
- Build against libtirpc
* Tue Feb 27 2018 cbosdonnat@suse.com
- Remove unneeded createrepo build dependency (bsc#1082689)
- builder-repository: fix SLES short id computation
  Patch added:
    0a55098f-builder-repository-fix-compute_short_id-for-sles-X.0.patch
- Fix handling of Latin-1 encoding in rpmdb (bsc#1075803)
  Patches added:
    0001-Introduce-a-wrapper-around-xmlParseURI.patch
    0002-common-extract-UTF-8-conversion-function.patch
    0003-inspector-rpm-summary-and-description-may-not-be-utf.patch
* Fri Feb 23 2018 adam.majer@suse.de
- Remove dependency on wodim for openSUSE:Factory and use cdrtools
  (bnc#1081739)
* Fri Feb  9 2018 cbosdonnat@suse.com
- update to version 1.38.0:
  * Virt-builder-repository is a new tool allowing end users to
    create and update virt-builder repositories. (fate#318952)
  * Virt-rescue has been substantially rewritten, implementing job
    control, -m and -i options, escape keys, etc.
  * Virt-builder planner has been improved so that faster and more
    efficient build plans are chosen for complex cases, especially when
    either the tmpdir or output is on networked storage.
  * Virt-customize now sets a random /etc/machine-id for Linux guests, if
    one is not already set.
  * Virt-df now works correctly on filesystems with block sizes smaller
    than 1K.
  * Virt-dib has further compatibility enhancements with diskimage-builder.
  * Virt-sysprep removes "DHCP_HOSTNAME" from ifcfg-* files.
  * Virt-resize now correctly copies GPT partition attributes from the
    source to the destination. (bsc#1074585)
  * Bash tab completion implemented or enhanced for: virt-win-reg,
    virt-v2v-copy-to-local.
  * Both virt-v2v and virt-p2v are now able to pass through the source CPU
    vendor, model and topology.
  * Virt-v2v now supports encrypted guests.
  * Virt-v2v now detects the special Linux Xen PV-only kernels correctly
  * Virt-v2v -o glance now generates the right properties for UEFI guests
  * Virt-v2v -o null now avoids spooling the guest to a temporary file,
    instead it writes to the qemu "null block device".  This makes it
    faster and use almost no disk space.
  * Virt-v2v -i libvirtxml can now open network disks over http or https.
  * Virt-v2v will now give a warning about host passthrough devices
  * Inspection support was rewritten in OCaml and included inside the
    daemon.  This makes inspection considerably faster, more robust and
    more easily extensible in future.
  * The libguestfs API is now thread-safe (although not parallel).  You can
    call APIs on the same handle from multiple threads without needing to
    take a lock.
- Removed patches:
    531316cc-build-improve-and-simplify-distro-detection.patch
    9d25b4e5-python-add-simple-wrappers-for-PyObject-string-funct.patch
    f3f99a09-python-use-right-func-when-PyString_FromStringAndSiz.patch
- Added patches:
    d0e5a819-python-Fix-missing-additional-backslashes.patch
* Mon Dec  4 2017 cbosdonnat@suse.com
- evtxdump is in python3-evtx, drop python2 dependency
  (fate#323526)
- add hwinfo to the appliance packages for ntfs support.
  (bsc#1070976)
- Don't run fdupes as it symlinks some of the python3 binding
  files to their python2 equivalent
* Wed Nov 22 2017 cbosdonnat@suse.com
- Add db48-utils dependency: needed to inspect the installed
  packages.
- Remove useless patch: 0000-hotfix.patch
* Wed Oct 25 2017 cbosdonnat@suse.com
- Move guestfs-data to libguestfs0. bsc#1064399
- Force distro detection
  Removed:
  * use-idlike.patch
  Added:
  * 531316cc-build-improve-and-simplify-distro-detection.patch
* Thu Oct 12 2017 sbrabec@suse.com
- Use "OCaml" in RPM group exactly as all other packages do.
* Thu Sep 21 2017 jengelh@inai.de
- Update summaries and RPM groups. Trim description for size.
- Replace old $RPM_ shell vars by macros.
  Remove redundant %%clean section.
* Wed Sep 20 2017 cbosdonnat@suse.com
- Add windows support files to the appliance for SLES (fate#316274)
- Merge SLES and openSUSE spec files.
* Mon Sep  4 2017 cbosdonnat@suse.com
- Tweak configuration before building for python3 or PyString_*
  symbols will still be missing
* Thu Aug 31 2017 cbosdonnat@suse.com
- Fix python binding for python3
  add patches:
  * 9d25b4e5-python-add-simple-wrappers-for-PyObject-string-funct.patch
  * f3f99a09-python-use-right-func-when-PyString_FromStringAndSiz.patch
- Better fix for SUSE distro detection using ID_LIKE as fallback:
  * use-idlike.patch
* Tue Jul 18 2017 cbosdonnat@suse.com
- Add missing dependency on guestfs-data (bsc#1048848)
- Add conflict with old virt-v2v (bsc#1050069)
- Fix python binding package
  * Replace python-libguestfs by python[23]-libguestfs packages
  * Add egg-info to python[23]-libguestfs package
* Mon Jul 17 2017 dmueller@suse.com
- add dependency on augeas (bsc#1048620)
* Sun Jul 16 2017 dmueller@suse.com
- update to version 1.36.5:
  * btrfs_replace: fix position of subcommand options
  * lib: Move close_file_descriptors into guestfs-internal.h.
  * daemon: lvm: Pass --yes option to force pvresize (RHBZ#1460577).
  * lib: direct, uml: Unblock SIGTERM in the hypervisor and recovery processes (RHBZ#1460338).
  * lib: create: Allow any [[:alnum:]]+ string as a backingfmt parameter (RHBZ#1459979).
  * mllib: Handle empty files correctly in read_first_line_from_file.
  * resize: make sure the input disk is read-only
  * v2v: tell v2v the real root device to mkinitrd
  * mllib: Export which in "stdlib mode".
  * mllib: Export prog, quiet, trace, verbose in "stdlib mode".
  * btrfs_replace: fix position of subcommand options
- add download location for source verification purposes
* Thu Jun  1 2017 cbosdonnat@suse.com
- Fix v2v conversion of SLES 11 SP4 with kdump enabled
  bsc#1038397
* Tue May 30 2017 ohering@suse.de
- Update to version 1.36.4
  ... to fix build with gperf 3.1
* Mon May 15 2017 cbosdonnat@suse.com
- Don't let mkinitrd guess the root device (bsc#1038397)
* Thu Apr  6 2017 cbosdonnat@suse.com
- Add ldmtool to appliance (fate#320858)
- Add cdrkit-cdrtools-compat to appliance, required for isoinfo*
  APIs to work.
* Wed Nov 30 2016 cbosdonnat@suse.com
- Add initviocons to appliance package (bsc#1011940)
* Thu Sep 22 2016 cbosdonnat@suse.com
- Backport btrfs-related fixes (bsc#1000202)
  commits: d6bba9b, f90185d, 4e0dbf9 and 738c3bf
* Mon Sep 19 2016 cbosdonnat@suse.com
- Add mount.ntfs alternatives symlink for SLES too (fate#316274)
* Wed Sep 14 2016 ohering@suse.de
- Remove obsolete kernel checks from specfile (fate#316274)
- Remove kernel-default and mkinitrd from BuildRequires (fate#316274)
* Fri Aug 26 2016 cbosdonnat@suse.com
- Clean up dependencies and add recommends for optional packages
  like the ones enabling file system features
  fate#316274, bsc#993501
* Thu Jul 28 2016 cbosdonnat@suse.com
- Fix dependencies (fate#316274)
* Wed Jul 20 2016 cbosdonnat@suse.com
- appliance fixes (fate#316274):
  * re-add helper script mount-rootfs-and-chroot.sh for virt-rescue
    appliance.patch
  * make guestfs-data a requirement of guestfs-tools
* Wed Jul 20 2016 cbosdonnat@suse.com
- v2v: add support for win2k16.
  Backport commit e93d4ea3, fate#316274
* Wed Jul 13 2016 ke@suse.de
- Fix virt-p2v package summary (dummy bsc#933411).
* Mon Jul  4 2016 cbosdonnat@suse.com
- Fix guestfs-tools dependencies. bsc#986866
* Wed Jun  8 2016 cbosdonnat@suse.com
- Fix virt-filesystem -l for btrfs. bsc#980092
- Add p2v support (fate#316274)
* Mon Mar 14 2016 cbosdonnat@suse.com
- Update to version 1.32.4
- Backported commits (fate#316274):
  * f5a9cdf: api: add mountable_device and mountable_subvolume
  * 1c30c23: fish: fix btrfs subvolumes display in error case
  * 1f24364: v2v: win <= 7: reduce registry patch
  * f0dce24: v2v: win >= 8: reduce registry patch
  * 9a441b0: v2v: win >= 8: simplify registry patching
  * e07459d: v2v: win: factor out common bits in registry patching
  * 47aa64a: v2v: add support for virtio-scsi
  * bba9ea9: v2v: also search for windows virtio drivers in symlinks
  * 3bf7d30: Update packagelist for SLES and openSUSE
  * 89ae53e: appliance: skip /etc/mtab creation is already existing
  * ee78c06: customize: add support for pvvxsvc
  * 25848b5: v2v: document SUSE's Xen as a working input hypervisor
  * e9082ea: v2v: rename RHEL 5 Xen input section into Xen in man
  * 75fe93e: v2v: improve initrd search
  * 536ef6f: customize: change windows firstboot path
  * 07f7bfa: customize: fix windows firstboot script
  * c466d4c: v2v: add support for SUSE VMDP drivers
  * 9de9300: v2v: handle subfolders in ova files
- Removed patches:
  * 1000-force-virtio_blk-in-old-guest-kernel.patch
  * libguestfs.mkinitrd.1110.patch
  * libguestfs.mkinitrd.1115.patch
  * libguestfs.mkinitrd.1140.patch
  * libguestfs.mkinitrd.1210.patch
  * libguestfs.mkinitrd.1220.patch
  * libguestfs.mkinitrd.1230.patch
  * libguestfs.mkinitrd.1310.patch
  * libguestfs.mkinitrd.boot-btrfs.sh
  * libguestfs.mkinitrd.boot-dm.sh
  * libguestfs.mkinitrd.boot-lvm2.sh
  * libguestfs.mkinitrd.boot-md.sh
  * libguestfs.mkinitrd.boot-nfs.sh
  * libguestfs.mkinitrd.boot.sh
  * libguestfs.mkinitrd.setup-btrfs.sh
  * libguestfs.mkinitrd.setup-dm.sh
  * libguestfs.mkinitrd.setup-lvm2.sh
  * libguestfs.mkinitrd.setup-md.sh
  * libguestfs.mkinitrd.setup-nfs.sh
  * libguestfs.mkinitrd.setup.sh
  * libguestfs.mkinitrd.tar.bz2
* Thu Oct  1 2015 cbosdonnat@suse.com
- Add password default encryption method for sles. fate#318952
* Tue Sep 29 2015 cbosdonnat@suse.com
- Add -l to zypper for install and update.
* Mon Sep 14 2015 cbosdonnat@suse.com
- Create the .cache folder if it doesn't exist already.
  bsc#939097.
* Wed Sep  9 2015 cbosdonnat@suse.com
- Define SHA512 as the default password encryption method for
  opensuse 11+.
* Mon Sep  7 2015 cbosdonnat@suse.com
- Add opensuse images source for virt-builder.
  fate#318952.
* Tue Jul 28 2015 cbosdonnat@suse.com
- Make sure gpg-agent isn't blocking unmount operations for
  fedora 22+ images. boo#939105
* Fri Jul 24 2015 ohering@suse.de
- Add rpmlintrc to surpress binaryinfo-readelf-failed to reduce
  build-compare noise
* Mon Jul 20 2015 ohering@suse.de
- Refresh libguestfs.mkinitrd.1310.patch
* Mon Mar  9 2015 ohering@suse.de
- Force feature usb into initrd to avoid build-compare noise
* Mon Mar  9 2015 ohering@suse.de
- Workaround bug in patch(1) which does not follow symlinks anymore
* Tue Feb 24 2015 ohering@suse.de
- Update to version 1.26.10
  * gcc5: test-tool: Initialize local variable.
  * lua: Define luaL_checkint which was deprecated in lua 5.3.
  * tools: fix free -m invocation
* Fri Feb  6 2015 cbosdonnat@suse.com
- Make zypper called with -n parameter when installing packages.
  (bsc#916567)
* Tue Dec  9 2014 ohering@suse.de
- Package guestfs_lvm_conf.aug (bnc#908632)
* Wed Nov 26 2014 ohering@suse.de
- Handle more dist versions when patching mkinitrd
* Mon Nov 24 2014 ohering@suse.de
- Add isofs and other fs drivers (bnc#906692)
* Mon Nov 24 2014 ohering@suse.de
- Use fixed /etc/hosts, scsi_dh_modules and ibft_hostname to
  reduce build-compare noise
* Thu Oct 16 2014 ohering@suse.de
- Handle btrfs subvolume name '@' as used in SLE12 (bnc#900346)
* Tue Oct 14 2014 ohering@suse.de
- Include gconv modules for hivex (bnc#900530)
* Fri Sep  5 2014 ohering@suse.de
- Update to version 1.26.9
  * customize: fix locking accounts with passwords
  * daemon: lvm-filter: use augeas for setting the filter
  * daemon: move AUGEAS_ERROR to the common header
  * daemon: add add_sprintf
* Tue Aug 26 2014 ohering@suse.de
- Update to version 1.26.8
  * mllib: Export output_spaces function.
  * daemon: Fix echo-daemon so it doesn't fail on empty array input.
  * drives: fix deletion of servers on error
  * daemon: zfile: call pclose instead of fclose
  * utils: Add new CLEANUP_PCLOSE cleanup.  It calls pclose(3).
  * launch: direct: Only issue Debian /dev/kvm group warning if /dev/kvm wasn't openable (RHBZ#1130189).
  * lib: Missing include of <locale.h>.
  * python: fix possible free on uninit memory with OStringList optargs
  * df: unlock retire_mutex on early exit
  * daemon: use CLEANUP_CLOSE
  * daemon: blkid: fix memory issues in "no -p/-i" mode
  * daemon: initialize memory when handling DeviceList params
  * rescue: fix sscanf placeholders for --smp and --memsize
  * daemon: add and use a reply_with_unavailable_feature macro
* Thu Jul 31 2014 ohering@suse.de
- Fix build without ocaml
* Thu Jul 31 2014 ohering@suse.de
- Update to version 1.26.7
  * launch: Close file descriptors after fork (RHBZ#1123007).
  * Revert "launch: Close file descriptors after fork (RHBZ#1123007)."
  * launch: direct: check for null paths in make_uri
  * make-fs: do not leak the fd from mkstemp
  * make-fs: respect libguestfs' temporary dir
* Thu Jul 31 2014 ohering@suse.de
- define kernel_binary on aarch64
* Mon Jul 28 2014 ohering@suse.de
- Update to version 1.26.6
  * cleanups: add CLEANUP_FCLOSE (fclose on FILE*)
  * launch: Close file descriptors after fork (RHBZ#1123007).
  * virt-resize: Unmount filesystem after testing size.
  * daemon: Add extra debugging to umount_all command.
  * sparsify: Relax requirement that output device cannot be block device (RHBZ#1122557).
  * ocaml: Ignore Warning 3: deprecated feature: String.* functions.
  * sysprep: Standard exception handling, taken from virt-builder & virt-v2v.
  * customize: Use Common_utils.error function instead of failwith.
  * mllib: introduce Mkdtemp.temp_dir
  * inspect: ignore /etc/fstab with no entries (RHBZ#1113156).
* Wed Jul  9 2014 ohering@suse.de
- Include fdisk and bc (bnc#886372)
* Tue Jul  8 2014 ohering@suse.de
- add Requires: qemu 2 to guestfs-tools to restore versioned kvm
* Tue Jul  8 2014 ohering@suse.de
- Use /usr/bin/qemu-system-ppc64 as kvm_binary on ppc64le (bnc#884564)
* Tue Jul  8 2014 ohering@suse.de
- Handle empty /lib/mkinitrd/scripts gracefully
* Mon Jul  7 2014 ohering@suse.de
- Update requirements for kvm package. Instead of calling qemu-kvm
  and Requires: kvm, replace the Requires with /usr/bin/qemu-system-$ARCH
  Define the helper for aarch64, ppc64, s390x and x86_64.
  Other archs have to use LIBGUESTFS_HV= (bnc#884564)
* Mon Jul  7 2014 ohering@suse.de
- Update to version 1.26.5
  * generator: Sort the structs.
  * Use -v and -x flags consistently across OCaml virt-* tools.
  * mllib: Rewrite text wrapping function so it can handle newlines within the text.
  * mllib: Add a common 'warning' utility function.
  * mllib: Add an interface for Common_utils library.
  * mllib: Move common code for comparing version strings to library.
  * options: Compile out part of union which cannot be used when not compiling guestfish.
  * mllib: Create a common utility function is_directory.
  * fuse: UID 0 should override all permissions checks (RHBZ#1106548).
  * launch: libvirt: Only use serial BIOS (sgabios) on x86.
  * daemon: print parameters for vgchange in error messages
  * generator: fix daemon functions with optional params but no mandatory params
  * appliance: Increase udev timeout to 6000s (RHBZ#1096579).
  * launch: libvirt: Add -device sga (sgabios).
* Fri Jul  4 2014 ohering@suse.de
- Add cdrkit-cdrtools-compat, psmisc, gptfdisk, syslinux to
  BuildRequires to reduce amount of missing commands
* Fri Jul  4 2014 ohering@suse.de
- Include mkinitrd scripts for btrfs, and include it in feature list
* Wed Jul  2 2014 ohering@suse.de
- Include mkinitrd scripts from lvm2, device-mapper, mdadm and
  nfs-client for 13.2 builds. The scripts will be removed from these
  packages, they are required here. (bnc#883863, bnc#883873,bnc#883876)
* Thu Jun  5 2014 mlatimer@suse.com
- Fix permissions on initramfs to allow regular users access.
* Mon May 26 2014 ohering@suse.de
- Update to version 1.26.3
  * ppc64: Use console=hvc0 console=ttyS0.
  * fish: simplify output of 'supported'
  * Fix some spelling mistakes and typos in documentation (RHBZ#1099284).
  * configure: Move --with-default-backend test later in configure.ac.
  * Fix handling of passwords in URLs
* Tue May 13 2014 ohering@suse.de
- Update to version 1.26.2
  * sparsify: Add a note about qcow2 internal snapshots not being copied (RHBZ#1094746).
  * customize: random-seed file has moved again.
  * lib: xmlParse{File,Memory} -> xmlRead{File,Memory}
  * launch: direct: Supply -M option when testing qemu for devices.
  * tar-in: Fix places where we didn't cancel the receive (FileIn) correctly along error paths (RHBZ#1091803).
  * configure: Make sure grep matches qemu 2.x version string.
  * daemon: parted: part-get-name: switch from sgdisk to parted (RHBZ#1088424).
  * sparsify: If using -v (verbose), ensure #disk_create runs verbose too.
  * disk-create: Fix this API so it works correctly with block devices (RHBZ#1088262).
  * listfs: If LDM not available, don't inhibit partition detection (RHBZ#1079182).
  * mllib: utils: Add mapi function.
  * src/launch: improve the addition of the no-hpet option
  * handle: Free g->backend_settings.
  * python: Remove unnecessary library dependencies.
  * utils: Move guestfs___validate_guid out of utils.c.
  * utils: Remove for-loop variable decl.
  * rescue: Don't leak various variables when using --suggest option with multi-boot guests.
  * make-fs: Close FILE* along error path.
  * make-fs: Check for error return from guestfs_statvfs.
  * daemon: parted: part-get-name: Don't leak partition type string.
* Fri Mar 28 2014 ohering@suse.de
- Update to version 1.26.0
  * virt-customize is a new tool for customizing disk images
  * virt-diff is a new tool for showing differences between filesystems
  * virt-sparsify has a new --in-place option
  * new virt-sysprep operations
  * many bug fixes
  * full release notes: http://libguestfs.org/guestfs-release-notes.1.html
- added 0000-hotfix.patch
- removed 0001-ocamlopt.patch
* Thu Feb 27 2014 ohering@suse.de
- Build without ocaml.opt on s390x and ppc64le
  0001-ocamlopt.patch
* Wed Feb 12 2014 ohering@suse.de
- Update to version 1.24.6
  * FAQ: Another common problem is permission denied errors when running as root.
  * FAQ: Add another common Ubuntu appliance problem.
  * list-filesystems: Do not segfault if guestfs_btrfs_subvolume_list returns an error (RHBZ#1064008).
  * actions/part_set_gpt_type: set type of "guid" parameter as "GUID" (RHBZ#1008417).
  * generator: generate code for parameter validation
  * generator: add a GUID parameter type
  * utils: add a function to validate a GUID string
  * Remove bogus license file from daemon subdirectory.
  * daemon: Always pass -F option to mkfs.ntfs.
  * resize: Don't truncate libguestfs error messages.
  * libvirt-domain: Remove unnecessary and wrongly indented parens.
  * fish/uri: Tidy up error messages.
  * daemon: lvm2: Ignore "unknown device" output when a PV is missing (RHBZ#1054761).
  * generator/set-uuid: Fix two typos in documentation
  * sparsify: Prevent overwriting block or char output devices (RHBZ#1056290).
  * test-tool: Rearrange output into alphabetical order.
* Tue Feb  4 2014 ohering@suse.de
- more testcases for SLE12, using grub2
  libguestfs.test.simple.create-sles12-guest.sh
  libguestfs.test.simple.create-sles12-guest-crypt-on-lvm.sh
* Thu Jan 30 2014 ohering@suse.de
- add BuildRequires:  ocaml(ocaml.opt)
* Wed Jan 29 2014 ro@suse.de
- drop i586 from ExclusiveArch as SLE-12 does not build a runnable
  kernel there, and KVM is 64bit only
* Thu Jan 23 2014 ohering@suse.de
- Disable ipv6 in the appliance because qemu usernet is ipv4 only
* Wed Jan 22 2014 ohering@suse.de
- add libguestfs-test subpackage, /usr/share/guestfs (fate#316275)
  libguestfs.test.simple.run-libugestfs-test-tool.sh
  libguestfs.test.simple.create-opensuse-guest.sh
  libguestfs.test.simple.create-opensuse-guest-crypt-on-lvm.sh
* Mon Jan 20 2014 ohering@suse.de
- Update to version 1.24.5
  * launch: Allow backend = "appliance" for backwards compatibility (RHBZ#1055452).
  * daemon: Use wipefs_has_force_option to decide whether to add wipefs --force option.
  * init: Display clocksource (only when debugging is enabled).
  * launch: direct: Make sure we pass lpj= parameter when using TCG.
  * Use recommended timer settings for KVM (RHBZ#1053847).
  * fuse: clear stat structs (RHBZ#660687).
  * fuse: remove extra trailing \n in debug messages
* Mon Jan 20 2014 ohering@suse.de
- Include crypto modules in appliance to enable luks related commands
* Mon Jan 20 2014 ohering@suse.de
- Resolve also library dependencies of libnss in mkinitrd (bnc#847785)
- BuildRequire nfs-utils to get mount.nfs, for virt-rescue
* Thu Jan 16 2014 ohering@suse.de
- Include mkinitrd from 13.1 when building appliance for 13.2 or
  later because dracut can not be used as replacement for mkinitrd
  and supermin is not ready yet
* Tue Jan  7 2014 ohering@suse.de
- Update to version 1.24.4
  * ruby: Fix .new method (RHBZ#1046509).
  * RHEL 6: ruby: Fix fallback to rake/rdoctask for old rake.
  * inspect: fix detection of newer CirrOS versions (RHBZ#1045450).
  * launch: libvirt: Clearer message when libvirt screws up.
  * fish: Fix memory leak in inspect/-i code (detected by valgrind).
  * appliance: Create an /etc/resolv.conf file referring to qemu user network nameserver (RHBZ#1044585).
  * fish: Move -d option parsing to common function.
  * fish: Deprecate the -D option (prefer --no-dest-paths instead).
  * daemon: Improve error message for readlink call.
  * generator: Fix bug in documentation of guestfs_free_* functions.
  * fish: Ensure print_inspect_prompt can only be called by guestfish.
  * inspector: Ensure low-level inspection functions can only be called by virt-inspector.
  * virt-cat, virt-filesystems, virt-ls don't use libconfig.
  * resize: Move roundup64 function into common utilities.
  * fuse: provide a stub "flush" implementation (RHBZ#660687).
  * recipes: Use new style -a/-d options in virt-edit example.
  * daemon: mkfs: Use -I option to force mkfs.fat to write a filesystem over a whole device (RHBZ#1039995).
  * proto: Remove another error message which hides earlier error.
  * proto: Remove error message which hides earlier error.
  * lib: fix newline in error output (RHBZ#923355).
  * recipes: Add a recipe for masking a systemd service.
  * launch: direct: Pass -enable-fips option if qemu supports it.
  * fish: improve the command error messages
* Tue Dec 17 2013 ohering@suse.de
- Update to version 1.24.2
  * launch: Print program and version as part of standard debug output when launching the handle.
  * lua: Don't redefine lua_objlen if already defined.
  * lib: Make sure -lselinux is used when linking libguestfs.so.
  * daemon: btrfs: Upstream 'btrfs device add' command now needs '--force' option to work.
  * perl: Give error instead of crashing if optarg is not an array reference.
  * Avoid modulo bias in random password generation
  * mllib: Add a utility function for safely reading from /dev/urandom.
  * podwrapper: virt-install is not a libguestfs page.
  * Update to latest gnulib to get hash relicensing change (thanks Jim Meyering).
  * Fix fstab block device resolution for FreeBSD
* Tue Nov 26 2013 ohering@suse.de
- Update to version 1.24.1
  * virt-resize & virt-sysprep can now use URIs to work on remote disks
  * many new virt-sysprep operations
  * many bug fixes
  * full release notes: http://libguestfs.org/guestfs-release-notes.1.html
- guestfsd needs at least libaugeas0 >= 1.0.0
- Recommend bash-completion to avoid completion errors
* Fri Oct 18 2013 ohering@suse.de
- Update to version 1.22.7
  * fish: CVE-2013-4419: Fix insecure temporary directory handling for remote guestfish (bnc#845720).
  * sysprep: firstboot: Don't set `Created_files flag unless files are created.
  * firstboot: Add some debugging to the control script.
  * firstboot: Fix test for installing sysvinit scripts.
  * firstboot: Install both systemd and SysV init scripts.
  * firstboot: Start service after network only.
  * firstboot: Fix firstboot scripts so they work on Ubuntu.
  * edit: Add virt-edit --edit as an alias for virt-edit -e.
  * btrfs: Fix improper memmove usage in do_btrfs_subvolume_list (RHBZ#1018149).
  * daemon: xattr: Fix scope of cleanup buf to avoid memory leaks.
  * daemon: parted: Fix memory leak of list of strings.
  * daemon: Fix scope of cleanup functions to avoid memory leaks.
  * df: parallel: Add a debug message when work function returns an error.
  * daemon: 'exists' API should not follow broken symlinks.
  * sysprep: Don't remove /var/cache/apt/archives/partial directory.
  * firstboot: Invoke firstboot.sh script with 'start' parameter.
  * daemon: Don't set LD_PRELOAD for guestfsd children.
  * daemon: Fix xfs_info parser because of new format.
  * sysprep: Fix option quoting in manual page.
  * virt-df: parallel: Send debugging messages to stderr.
  * inspection: Don't print a warning if \Windows\explorer.exe does not exist.
  * launch: direct: Set QEMU_AUDIO_DRV=none to stop qemu opening audio devices.
  * virt-df: parallel: Compile debugging messages in always.
  * daemon: augeas: Don't test if AUG_NO_ERR_CLOSE is defined.
  * daemon: augeas: Enhance error reporting for aug_init failures.
  * drives: Don't need to call free_drive_servers since preceding code checks servers == NULL.
  * sparsify: Fix signal handling.
  * daemon: tar: Use a temporary file to pass excludes to tar command (RHBZ#1001875).
  * format: Set MBR partition type byte appropriately (RHBZ#1000428).
* Mon Oct 14 2013 ohering@suse.de
- Keep setup-dm.sh, required to copy dm rules (bnc#837595)
* Mon Sep 23 2013 ohering@suse.de
- Remove BuildRequires: qemu-tools
* Mon Sep 23 2013 ohering@suse.de
- Add static 169.254.0.0/16 network addresses (bnc#835949)
* Thu Sep 19 2013 ohering@suse.de
- Update to version 1.22.6
  * Initialize CLEANUP_* stack variables with NULL in various places.
  * daemon: sh: Fix missing initializer which caused segfault (RHBZ#1000121).
  * fish: Document that guestfish --remote --add won't work as expected (RHBZ#998513).
  * launch: direct: Don't try to wait for qemu if parent process forked (RHBZ#998482).
  * list-filesystems: Don't fail if there are no filesystems found (RHBZ#995711).
  * virt-list-filesystems: Fix to use $g->canonical_device_name instead of homebrew function.
  * daemon: If /proc/modules doesn't exist, linuxmodules optgroup is disabled.
  * launch: direct: Print \n after printing qemu command line.
  * conn: Make sure we display all log messages when qemu goes away.
  * lib: Turn 'random_chars' function used by libvirt backend into utility function.
  * daemon: ldm: Don't return an error if /dev/mapper doesn't exist.
  * daemon: Move all RESOLVE macros to daemon/stubs.c.
  * proto: Fix --enable-packet-dump mode.
  * daemon: Close augeas, hivex handles in unmount_all.
  * Fix parsing of boot flag in do_part_get_bootable()
  * Update gnulib to latest version.
  * augeas: Improve error reporting.
  * launch: direct: Add drives after machine parameters.
  * fish: Fix guestfish so it can recognize sheepdog://... as a valid URI.
  * resize: Move isatty_stdout function to separate module (TTY.isatty_stdout).
  * daemon: cap-get-file: Return empty string if no capability on file (RHBZ#989356).
  * src/file.c: Be sure to call guestfs___lazy_make_tmpdir before using g->tmpdir.
  * generator: Fix the case where a daemon function has one FileIn/FileOut parameter and no other parameters.
* Thu Sep 19 2013 ohering@suse.de
- Create symlink from /etc/mtab to /proc/self/mounts (bnc#840662)
* Mon Sep  2 2013 dvaleev@suse.com
- add ppc64 to Exclusive arch
* Thu Aug 29 2013 ohering@suse.de
- Add support for lvm (bnc#837595)
* Thu Aug 22 2013 ohering@suse.de
- Add network related modules to initrd (bnc#835949)
- Remove supermin.d
- Mount also /dev/pts in mount-rootfs-and-do-chroot.sh
- Handle rw option in ext4.ko
- Update libguestfs.mkinitrd.1210.patch to create /usr/*bin in 11.4
* Mon Aug 19 2013 ohering@suse.de
- Update to version 1.22.5
  * full support for btrfs guests
  * large performance improvements in virt-df and virt-alignment-scan tools
  * many bug fixes
  * full release notes: http://libguestfs.org/guestfs-release-notes.1.html
* Mon Aug  5 2013 ohering@suse.de
- Package /lib/udev or /usr/lib/udev in guestfsd subpackage
* Tue Jul 30 2013 ohering@suse.de
- Update to version 1.20.10
  * sysprep: On RHEL, firstboot script should be called S99... not 99.
  * fish: For -N option, add drive with explicit format = "raw".
  * daemon: Implement set-label for XFS and fix it for btrfs (RHBZ#986875).
  * mkfs: Use -b size=<size> for xfs (RHBZ#981715).
  * cmd: Allow callers to override file-closing behaviour after fork.
  * daemon: hivex: Check that hivex_commit is passed an absolute path (RHBZ#981683).
  * daemon: Verify ext2/3/4 filesystem name before passing to mke2fs (RHBZ#978302).
  * virt-resize: Add notes about Windows and disk consistency (RHBZ#975753).
  * virt-resize: Take into account large start offset of the first partition when calculating overhead (RHBZ#974904).
  * launch: direct: Calculate appliance root correctly when iface drives are added (RHBZ#975797).
* Sat Jun 15 2013 ohering@suse.de
- Update to version 1.20.9
  * txz-out: Fix this API to produce xz files again (RHBZ#972775).
  * inspect: Fix bogus warning for partitions without /boot.ini
  * inspect: Partial support for non-standard windows system root
  * events: Avoid event handler limit if program allocates and deallocates handlers.
  * proto: Fix for rare FileIn hangs. (RHBZ#969845)
  * inspection: Don't segfault if /etc/SuSE-release is an empty file.
  * fuse: Allow specifying the fstype of a mount
  * is_lv: Does not need to depend on lvm2.
  * add --with-supermin-extra-options configure option
  * Remove use of gnulib progname module.
  * inspection: Fix double-free when certain guest files are empty. (CVE-2013-2124)
  * daemon: Properly quote arguments for tar-out, base64-out commands (RHBZ#957772).
  * inspection: Don't fail if libosinfo database is not found (RHBZ#948324).
  * daemon/copy: Ensure errno is preserved along error
  * Better error messages for FUSE and other things not supported.
* Mon Apr  8 2013 ohering@suse.de
- force paths to supermin/supermin-helper even if package is not available at buildtime
* Tue Apr  2 2013 ohering@suse.de
- Update to version 1.20.5
  * daemon: file: Remove extraneous space after output of 'file' command (RHBZ#928995).
  * lib: Add missing cases in switch statements.
  * appliance: Make sure cachedir has mode 0755 (RHBZ#921292).
  * appliance: Use ignore_value() macro instead of casting return to (void).
  * launch: Print attach-method, tmpdir, umask, euid when launching.
  * utils: Fix error messages for external commands that fail (RHBZ#921040).
* Tue Apr  2 2013 ohering@suse.de
- make sure /etc/lvm/lvm.conf exists (bnc#812931)
* Fri Mar 22 2013 ohering@suse.de
- Update to version 1.20.4
  * launch: appliance: Add custom parameters last.
  * filearch: Don't print errno if cpio command fails, print command status instead.
  * proto: send_to_daemon is not an exported function.
* Mon Mar 18 2013 dmueller@suse.com
- use proper build conditionals so that it can be influenced
  outside spec file (via e.g. prjconf)
* Wed Mar  6 2013 ohering@suse.de
- Update to version 1.20.3
  * trace: Put trace buffer on the stack instead of in the handle.
  * FAQ: Add question about running fsck on live filesystems
  * lib: Check calls to xmlXPathEvalExpression for nodesetval == NULL.
  * recipes: Add example converting from one format/filesystem to another
  * daemon: protocol: Fix memory leak when receiving FileIn file (RHBZ#914934).
  * protocol: Don't segfault if appliance crashes during FileIn upload (RHBZ#914931).
  * libutils: Add guestfs___count_strings utility function to common library
  * lib: Create libutils convenience library.
  * docs: Rewrite security section (thanks Dan Berrange)
  * lib: Fix memory leak when the 'lpj' setting is read from dmesg.
* Mon Feb 25 2013 ohering@suse.de
- Update to version 1.20.2
  * proto: Fix stack overflow when there are many progress events (RHBZ#909624).
  * rescue: Count the mountable filesystems when displaying the 'suggest' message.
  * lib: Define CLEANUP_CMD_CLOSE macro and use it throughout the library.
  * lib: Allow guestfs_free_* functions to be safely called with a NULL pointer.
  * btrfs: Fix btrfs_subvolume_list on F18 (RHBZ#903620).
  * daemon: Check parameter of base64-out and tar-out before running external command (RHBZ#908322).
  * daemon: download: Add extra check that download file is not a directory (RHBZ#908321).
  * daemon: Add more information to certain calls to perror.
  * daemon: Call wipefs before mkfs to work around pathological behaviour in btrfs.
  * lib: Add CLEANUP_* macros which automatically free things when leaving scope.
  * header: Deprecate LIBGUESTFS_HAVE_* in favour of GUESTFS_HAVE_*.
  * fuse: Use guestfs_rename to implement rename(2) syscall (RHBZ#895910).
  * New API: rename: Rename file within the same filesystem (RHBZ#895910).
  * fuse: If guestfs_last_errno returns 0, don't return no error to FUSE layer.
  * daemon: Change ln, ln-f (hard-link) APIs to use link(2) instead of external ln (RHBZ#895905).
  * Fix checksums-out command (RHBZ#895904).
  * launch: appliance: Fix parsing of QEMU_OPTIONS.
  * launch: appliance: Small refactoring of virtio-scsi detection code.
* Mon Feb 25 2013 ohering@suse.de
- enable ruby bindings only in 12.2 or later, ruby is too fragile
* Sun Feb 24 2013 ohering@suse.de
- BuildRequire: perl-macros only in sles11 builds to fix build in 11.4
* Fri Jan 18 2013 ohering@suse.de
- more fixes for copying entire /etc/lvm directory (bnc#795503)
* Wed Jan 16 2013 ohering@suse.de
- disable strip and /usr/lib/rpm/find-debuginfo.sh for non-opt builds
  it destroys bytecode binaries
* Thu Jan  3 2013 ohering@suse.de
- handle more architectures than just x86 when looking for guest kernel
* Wed Jan  2 2013 ohering@suse.de
- Update to version 1.20.1
  * inspection: Set fs->device field on swap devices.
  * Pass noapic on i686 kernel command line.
  * daemon: Use pvcreate --force option (RHBZ#887971).
  * daemon: Fold stdout on stderr when running e2fsck.
  * other minor changes
* Wed Jan  2 2013 ohering@suse.de
- copy entire /etc/lvm directory in guestfsd (bnc#795503)
* Mon Dec 17 2012 ohering@suse.de
- correct initrd filename on i586 (bnc#794819)
* Thu Dec 13 2012 ohering@suse.de
- Update to stable branch, version 1.20.0
* Tue Dec 11 2012 ohering@suse.de
- add Conflicts: (libguestfs0|guestfs-data) with old versions to
  guestfs-tools to make sure all parts match the same API
* Thu Nov 29 2012 ohering@suse.de
- update BuildRequire ext4-writeable-kmp-default handling
  enable it unconditional in sles11 builds, but not in the
  Virtualization repo because its a private package.
* Thu Nov 29 2012 ohering@suse.de
- make perl-bindings (perl-Sys-Guestfs) optional, disabled for sles11
* Sun Nov 25 2012 ohering@suse.de
- include Pod-Simple-3.23.tar.gz to get perl(Pod::Simple::XHTML)
  at build time (bnc#789653)
- Update to version 1.19.64 (fate#312159)
* Mon Nov 19 2012 ohering@suse.de
- readd autoreconf -fi if automake is newer than 1.10
  it fixes ruby build failures due to RPATH ending up in libraries
  in 11.4 and 12.1
* Mon Nov 19 2012 ohering@suse.de
- Update to version 1.19.61
  new subpackage lua-libguestfs, disabled for sles11
* Wed Nov 14 2012 ohering@suse.de
- stick to upstream defaults:
  restore default attach mode, which is appliance,
* Wed Nov 14 2012 ohering@suse.de
- adjust License tag, libguestfs0 is LGPL-2.1, rest is GPL-2
- add COPYING.LIB to subpackage
- remove AUTHORS and README files from doc section
* Wed Nov 14 2012 ohering@suse.de
- remove guestfs-doc subpackage, it contains just exmple xml files
* Wed Nov 14 2012 ohering@suse.de
- remove autoreconf -fi, it fails with autoconf-1.10 as included
  in sles11 due to AM_SUBST_NOTMAKE usage
* Tue Nov 13 2012 ohering@suse.de
- Update to version 1.19.59
* Tue Nov 13 2012 ohering@suse.de
- disable python when building for SLES11
* Tue Nov 13 2012 ohering@suse.de
- split BuildRequires ocaml into ocaml_tools and ocaml_bindings
- disable ocaml_bindings when building for SLES11
* Tue Nov 13 2012 ohering@suse.de
- disable ruby when building for SLES11
* Thu Nov  8 2012 ohering@suse.de
- Update to version 1.19.57
* Mon Oct 29 2012 ohering@suse.de
- add BuildRequires aaa_base to get get_kernel_version
  handle get_kernel_version location in /sbin or /usr/sbin
* Fri Oct 19 2012 ohering@suse.de
- Update to version 1.19.53
* Wed Oct 10 2012 ohering@suse.de
- change default_attach_method from appliance to libvirt if the
  distro kernel includes virtio-scsi. This is true for 12.2+
  In 12.1 and older the attach_method remains appliance.
  The reason for this change is the creation of XML for libvirt,
  which is cumbersome for virtio-blk.
* Mon Oct  8 2012 ohering@suse.de
- make appliance optional when using libvirt as attach-method
* Mon Oct  8 2012 ohering@suse.de
- disable hivex and zerofree when building for SLES11
* Mon Oct  8 2012 ohering@suse.de
- Update to version 1.19.48
* Wed Oct  3 2012 ohering@suse.de
- make zerofree optional in the spec file
* Wed Oct  3 2012 ohering@suse.de
- remove obsolete virt-list-filesystems, virt-list-partitions and
  virt-tar comamnds
* Thu Sep 27 2012 ohering@suse.de
- add local patches to copy symlinks with mkinitrd (bnc#778149)
* Tue Sep 25 2012 ohering@suse.de
- add mount.ntfs and mount.fuse to initrd
* Mon Sep 24 2012 ohering@suse.de
- Update to version 1.19.44
* Mon Sep 24 2012 ohering@suse.de
- update virtio-blk patch to force vda in libguestfs-test-tool
* Mon Sep 24 2012 ohering@suse.de
- update mount-rootfs-and-do-chroot.sh, avoid bind mount errors
* Sat Sep 22 2012 ohering@suse.de
- Update to version 1.19.43
* Fri Sep 21 2012 ohering@suse.de
- reorder debug output in /init script, print partitions last
- mention mount-rootfs-and-do-chroot.sh in rescue message
* Thu Sep 20 2012 ohering@suse.de
- add mkdir, mount, chroot, umount to initrd command list, for 11.4
* Thu Sep 20 2012 ohering@suse.de
- use ttyS0 for setctsid if /proc/consoles does not exist
* Wed Sep 19 2012 ohering@suse.de
- enable augeas unconditionally also for sles11
* Wed Sep 19 2012 ohering@suse.de
- add augeas-lenses to BuildRequires in 11.4+ and package it in
  initrd, for virt-inspector
* Mon Sep 17 2012 ohering@suse.de
- Update to version 1.19.42
* Thu Sep 13 2012 ohering@suse.de
- move BuildRequires for subpackages into the subpackage section
* Thu Sep 13 2012 ohering@suse.de
- move Requires to guestfs-tools
* Thu Sep 13 2012 ohering@suse.de
- Use perl_requires macro in guestfs-tools
* Thu Sep 13 2012 ohering@suse.de
- add Requires libguestfs0 to libguestfs-devel to fix rpmlint warning
* Thu Sep 13 2012 ohering@suse.de
- fix rpmlint warnings about shlib-policy-missing-lib:
  move files from libguestfs to guestfs-tools
  rename libguestfs-guestfsd to guestfsd
  rename libguestfs-doc to guestfs-doc
  rename libguestfs-data to guestfs-data
* Thu Sep 13 2012 ohering@suse.de
- force virtio-blk usage only if the guest kernel has no virtio-scsi
* Thu Sep 13 2012 ohering@suse.de
- delete unused perl script without executable permissions to fix rpmlint warning
* Thu Sep 13 2012 ohering@suse.de
- delete empty perl bootstrap files to fix rpmlint warning
* Thu Sep 13 2012 ohering@suse.de
- adjust Summary of libguestfs0 to fix rpmlint warning
* Thu Sep 13 2012 ohering@suse.de
- show missing_commands only in verbose mode
* Wed Sep 12 2012 ohering@suse.de
- add jfsutils and reiserfs to BuildRequires to reduce number of missing_commands
* Wed Sep 12 2012 ohering@suse.de
- add chroot helper for virt-rescue, Bug 674684 - mount-rootfs-and-do-chroot.sh
* Wed Sep 12 2012 ohering@suse.de
- create /selinux in initrd, guestfsd tries to bind mount it into the guest
* Fri Sep  7 2012 ohering@suse.de
- copy terminfo files so that backspace works in screen
* Fri Sep  7 2012 ohering@suse.de
- run the rescue shell with setctsid so that it gets a controlling tty
* Wed Sep  5 2012 ohering@suse.de
- move all modules, except dm-mod, to udevmodules so that the are
  really loaded on demand
* Wed Sep  5 2012 ohering@suse.de
- include sparsify from zerofree.rpm, and strace in initrd
* Wed Sep  5 2012 ohering@suse.de
- use perl_gen_filelist to avoid packaging the "auto" directory
- this leads to build errors in SLE_11 repo
- perl_gen_filelist tries to package everything, remove all non-perl
  files from list to avoid duplicate files
* Wed Sep  5 2012 ohering@suse.de
- Update to version 1.19.40
* Tue Sep  4 2012 ohering@suse.de
- move additional modules to mkinitrd to prevent loading everything,
  rely on autoloading instead
- add also nls modules, remove ecrypt
* Tue Sep  4 2012 ohering@suse.de
- Update to version 1.19.39
* Tue Sep  4 2012 ohering@suse.de
- add also btrfs and ext4
* Tue Sep  4 2012 ohering@suse.de
- surprise: filesystem modules are required to mount a filesystem:
  9p cramfs ecryptfs ext2 ext3 fat fuse hfs hfsplus jfs minix ncpfs
  nfs quota reiserfs squashfs squashfs3 udf ufs xfs
* Tue Sep  4 2012 ohering@suse.de
- remove obsolete libguestfs-1.13.14-without-hivex.patch
* Tue Sep  4 2012 ohering@suse.de
- Update to version 1.19.38
* Mon Sep  3 2012 ohering@suse.de
- correct assignment for additional external commands
* Mon Sep  3 2012 ohering@suse.de
- actually enable the code to force virtio_blk
* Mon Sep  3 2012 ohering@suse.de
- add also the fsck.* commands because guestfsd can not provide such a list
* Mon Sep  3 2012 ohering@suse.de
- run format_specfile
* Mon Sep  3 2012 ohering@suse.de
- add dosfstools for mkfs.vfat/msdos
* Mon Sep  3 2012 ohering@suse.de
- move all BuildRequires for the initrd into the subpackage section
* Mon Sep  3 2012 ohering@suse.de
- add patch to force virtio_blk or virtio_scsi via environment variable
* Mon Sep  3 2012 ohering@suse.de
- update Group of ocaml-libguestfs-devel to fix rpmlint warning
* Mon Sep  3 2012 ohering@suse.de
- provide fixed list of mkfs subcommands because guestfsd can not
  export such list
* Mon Sep  3 2012 ohering@suse.de
- create /sysroot directory in initrd, guestfsd relies on it
* Mon Sep  3 2012 ohering@suse.de
- show more /proc/entries using head(1)
* Mon Sep  3 2012 ohering@suse.de
- add missing perl Requires, they are not automatically added at build time
* Mon Sep  3 2012 ohering@suse.de
- remove the LD_RUN_PATH patch
  The same result can appearently achieved by passing an empty LD_RUN_PATH to make
* Mon Sep  3 2012 ohering@suse.de
- quote %% in awk regex to avoid potential errors
* Mon Sep  3 2012 ohering@suse.de
- use perl macro to remove unwanted files from buildroot
* Mon Sep  3 2012 ohering@suse.de
- Reduce number of rpmlint warnings:
  update Group of doc and devel subpackage
  update Summary  and description of perl, python and ruby bindings
  trim description of ruby bindings
* Sun Sep  2 2012 ohering@suse.de
- update perl(Pod::Simple::XHTML) BuildRequires, and comment
* Sun Sep  2 2012 ohering@suse.de
- add hack to force virtio_blk instead of virtio_scsi
- because 12.1 and older kernels do not have virtio_scsi yet
* Sat Sep  1 2012 ohering@suse.de
- enable BuildRequires: perl(Win::Hivex)
* Sat Sep  1 2012 ohering@suse.de
- use versioned obsoletes to avoid self-obsoletes
* Sat Sep  1 2012 ohering@suse.de
- move guestfsd to subpackage libguestfs-guestfsd
* Sat Sep  1 2012 ohering@suse.de
- enable BuildRequires: perl(String::ShellQuote)
* Sat Sep  1 2012 ohering@suse.de
- move ocaml files to ocaml-libguestfs and ocaml-libguestfs-devel
* Sat Sep  1 2012 ohering@suse.de
- rename subpackage libguestfs-python to python-libguestfs
* Sat Sep  1 2012 ohering@suse.de
- rename subpackage libguestfs-perl to perl-Sys-Guestfs
* Fri Aug 31 2012 ohering@suse.de
- Update to version 1.19.37
* Fri Aug 31 2012 ohering@suse.de
- reenable ruby bindings, apply patch to fix failure in 11.4 and 12.1
  happens to work in sles11sp2 and 12.2 for some reason
* Fri Aug 31 2012 ohering@suse.de
- remove Version from libguestfs-data package, not needed.
- remove Requires from libguestfs-data package, not needed either.
* Fri Aug 31 2012 ohering@suse.de
- remove libguestfs.perl.install_vendor.patch
  INSTALLDIRS=vendor can be used to select a different dir
  (from Fedora libguestfs.spec)
* Fri Aug 31 2012 ohering@suse.de
- fix module loading, they have to be listed in a single line
- include magic files for file
* Fri Aug 31 2012 ohering@suse.de
- add iproute2 for ip command
* Fri Aug 31 2012 ohering@suse.de
- add workaround for copying symlinks in mkinitrd (bnc#778149)
* Fri Aug 31 2012 ohering@suse.de
- run mkinitrd with bash -x as a debugging aid
* Fri Aug 31 2012 ohering@suse.de
- add ntfs-3g
* Fri Aug 31 2012 ohering@suse.de
- remove compress
* Fri Aug 31 2012 ohering@suse.de
- add more packages to BuildRequires to reduce number of missing_commands
* Thu Aug 30 2012 ohering@suse.de
- Update to version 1.19.36
  Add patch to collect a list of all called binaries from guestfsd
- patch mkinitrd to copy links (bnc#778149)
* Thu Aug 30 2012 ohering@suse.de
- sort modules and programs in initrd
* Thu Aug 30 2012 ohering@suse.de
- add blockdev from util-linux to initrd
* Thu Aug 30 2012 ohering@suse.de
- build with parted, for virt-alignment-scan
* Thu Aug 30 2012 ohering@suse.de
- use final filename for initrd and vmlinuz to simplify copying from build chroot
* Thu Aug 30 2012 ohering@suse.de
- Update to version 1.19.35
  disable java
  remove kvm and qemu from BuildRequires, the path to qemu-kvm
  can be passed to configure
* Wed Aug 29 2012 ohering@suse.de
- remove buildtime dependency of kvm
* Wed Aug 29 2012 ohering@suse.de
- build appliance as initramfs image with the help of mkinitrd
* Wed Aug 29 2012 ohering@suse.de
- enable and install the guestfs daemon
* Wed Aug 29 2012 ohering@suse.de
- build with attr-devel
* Wed Aug 29 2012 ohering@suse.de
- build with file-devel
* Wed Aug 29 2012 ohering@suse.de
- build with augeas in openSUSE 11.4 and later
* Wed Aug 29 2012 ohering@suse.de
- build with libconfig in openSUSE 12.2 and later
* Wed Aug 29 2012 ohering@suse.de
- split perl patch libguestfs-1.19.30.patch into
  libguestfs.perl.install_vendor.patch and libguestfs.perl.no-rpath.patch
  Both are needed in upcoming versions
* Wed Aug 29 2012 ohering@suse.de
- remove obsolete patches
  libguestfs-1.13.14-disable-erlang.patch
  libguestfs-1.13.14-no-machine.patch
  libguestfs-1.13.14-provided-appliance.patch
* Wed Aug 29 2012 ohering@suse.de
- Update to version 1.19.34
  enable fuse support
* Fri Aug 24 2012 ohering@suse.de
- require at least kvm 1.1 at runtime
* Mon Aug 20 2012 ohering@suse.de
- Update to version 1.19.32
* Mon Aug 20 2012 ohering@suse.de
- package ocaml directory to fix build
* Mon Aug 20 2012 ohering@suse.de
- enable ocaml for sparsify
* Sat Aug 18 2012 ohering@suse.de
- Require kvm, to get /usr/bin/qemu-kvm
- move devel man pages to devel package
* Fri Aug 17 2012 ohering@suse.de
- force usage of Pod::Simple::XHTML from this project to fix build in 11.4
* Thu Aug 16 2012 ohering@suse.de
- run /usr/lib/obs/service/format_spec_file
* Thu Aug 16 2012 ohering@suse.de
- disable qemu test.
  If the package is built within kvm the configure test will fail
  because it starts kvm within kvm
* Thu Aug 16 2012 ohering@suse.de
- require Pod::Simple::XHTML for podwrapper.pl
* Thu Aug 16 2012 ohering@suse.de
- add more groups to enable sles11 build
* Thu Aug 16 2012 ohering@suse.de
- Add Group: Documentation to fix build in sles11
* Thu Aug 16 2012 ohering@suse.de
- RPM_OPT_FLAGS can not be used with configure macro, use CFLAGS instead
* Thu Aug 16 2012 ohering@suse.de
- remove libguestfs.files reference
* Thu Aug 16 2012 ohering@suse.de
- disable ruby, uses -Wl,-R
- build with -Wno-unused
- touch file list
* Wed Aug 15 2012 ohering@suse.de
- Update to version 1.19.30
  move python, perl and ruby bindings to extra package
* Tue Aug  7 2012 ohering@suse.de
- ExclusiveArch x86
* Mon Jul  2 2012 ohering@suse.de
- fix filelist to build on sles11
* Fri Sep 30 2011 mhrusecky@suse.cz
- disabling dependencies not present in Factory
  * will enable them once they will be available
* Thu Sep 29 2011 mhrusecky@suse.cz
- shrinking virtual image
- making virtual machine data dependent on libguestfs
* Tue Sep 27 2011 mhrusecky@suse.cz
- enabling more dependencies (fuse, hivex, libconfig)
- providing ruby bindings
* Mon Sep 26 2011 mhrusecky@suse.cz
- Initial package (version 1.13.14)
  * no bindings yet
  * no fuse
  * no febootstrap
  * sample virtual machine included
